##################################################
# import data and add geometry data
#
# active shots are files 80.H to 110.H
# passive recording of the motorcycle generated noise is from file 112.H to 129.H
#
#################################################################################
# Receiver layout and channel numbering.
# The geophones were connected to the geode in the order of channels specified here.
#--------------------------
#
# Az=30 (+Y)
# ^
# |
# |
# |
# |						G22(0.00,1.18)							G21(1.75,1.15)							G17(3.45,1.13)
# |
# |	G24(-0.90,0.00)		R(0.00,0.00)		G20(0.90,0.00)		R(1.75,0.00)		G18(2.60,0.00)		R(3.45,0.00)		G15(4.30,0.00)								G14(7.3,0.00) .... (13 more channels at 3m intervals till G1)
# |
# |						G23(0,00,-1.18)							G19(1.75,-1.15)							G16(3.45,-1.13)
# |
# |
# |
# |
# --------------------------------------------------> Az=120 (+X)
#################################################################################

${D}/%.H: ${SILVERLAKE}/%.sgy
	segyread tape=$< > ${D}/tmp.su
	Su2sep < ${D}/tmp.su > $@ hff=$@@@

input-geophones: \
	${D}/80.H ${D}/81.H ${D}/82.H ${D}/83.H ${D}/84.H ${D}/85.H ${D}/86.H ${D}/87.H ${D}/88.H ${D}/89.H \
	${D}/90.H ${D}/91.H ${D}/92.H ${D}/93.H ${D}/94.H ${D}/95.H ${D}/96.H ${D}/97.H ${D}/98.H ${D}/99.H \
	${D}/100.H ${D}/101.H ${D}/102.H ${D}/103.H ${D}/104.H ${D}/105.H ${D}/106.H ${D}/107.H ${D}/108.H ${D}/109.H \
	${D}/110.H ${D}/111.H ${D}/112.H ${D}/113.H ${D}/114.H ${D}/115.H ${D}/116.H ${D}/117.H ${D}/118.H ${D}/119.H \
	${D}/120.H ${D}/121.H ${D}/122.H ${D}/123.H ${D}/124.H ${D}/125.H ${D}/126.H ${D}/127.H ${D}/128.H ${D}/129.H \
	${D}/130.H

${D}/all-active-vz.H: \
	${D}/80.H ${D}/81.H ${D}/82.H ${D}/83.H ${D}/84.H ${D}/85.H ${D}/86.H ${D}/87.H ${D}/88.H ${D}/89.H \
	${D}/90.H ${D}/91.H ${D}/92.H ${D}/93.H ${D}/94.H ${D}/95.H ${D}/96.H ${D}/97.H ${D}/98.H ${D}/99.H \
	${D}/100.H ${D}/101.H ${D}/102.H ${D}/103.H ${D}/104.H ${D}/105.H ${D}/106.H ${D}/107.H ${D}/108.H ${D}/109.H \
	${D}/110.H
	Cat3d $^ > $@ hff=$@@@

${D}/all-passive-vz.H: \
	${D}/112.H ${D}/113.H ${D}/114.H ${D}/115.H ${D}/116.H ${D}/117.H ${D}/118.H ${D}/119.H \
	${D}/120.H ${D}/121.H ${D}/122.H ${D}/123.H ${D}/124.H ${D}/125.H ${D}/126.H ${D}/127.H ${D}/128.H ${D}/129.H
	Cat3d $^ > $@ hff=$@@@
	echo "n3=1" >> $@
	echo "n2=432" >> $@
	echo "n3=1" >> $@@@
	echo "n2=432" >> $@@@


${D}/good-active-vz.H: ${D}/80.H ${D}/81.H ${D}/82.H ${D}/83.H ${D}/93.H ${D}/94.H ${D}/95.H ${D}/96.H ${D}/97.H ${D}/98.H ${D}/99.H \
	${D}/102.H ${D}/103.H ${D}/104.H ${D}/105.H ${D}/106.H ${D}/107.H ${D}/108.H ${D}/109.H ${D}/110.H
	Cat3d $^ > $@ hff=$@@@
	echo "n3=1" >> $@
	echo "n2=480" >> $@
	echo "n3=1" >> $@@@
	echo "n2=480" >> $@@@


# the receiver layout is hardcoded into the file ${SILVERLAKE}/gxgy.H in ascii.
# this changes the format to floats, and then concatenates the file #shot times so it can be merged with the data headers
${D}/gxgy.H: ${SILVERLAKE}/gxgy.H
	Dd < $< ein=0 esize=4 > ${D}/tmpg.H
	Cat axis=1 ${D}/tmpg.H ${D}/tmpg.H ${D}/tmpg.H ${D}/tmpg.H ${D}/tmpg.H ${D}/tmpg.H ${D}/tmpg.H ${D}/tmpg.H ${D}/tmpg.H ${D}/tmpg.H \
	${D}/tmpg.H ${D}/tmpg.H ${D}/tmpg.H ${D}/tmpg.H ${D}/tmpg.H ${D}/tmpg.H ${D}/tmpg.H ${D}/tmpg.H ${D}/tmpg.H ${D}/tmpg.H | Transp > $@
	@Rm ${D}/tmpg.H

${D}/good-active-vz2.H: ${D}/good-active-vz.H ${D}/gxgy.H
	cp $< ${D}/tmpvz.H
	echo "hff=-1" >> ${D}/tmpvz.H
	Cp ${D}/tmpvz.H $@
	Merge $<@@ ${D}/gxgy.H axis=1 space=n > $@@@
	echo 'hdrkey16="Gx"    hdrtype16="scalar_float"   hdrfmt16="xdr_float"' >> $@@@
	echo 'hdrkey17="Gy"    hdrtype17="scalar_float"   hdrfmt17="xdr_float"' >> $@@@
	echo "hff=$@@@" >> $@
	
${D}/active-vz.H: ${D}/good-active-vz2.H
	Headermath < $< \
	key1=Sx type1=scalar_float eqn1="sx*1.-1." \
	key2=Sy type2=scalar_float eqn2="sx*0." \
	key3=Offsetx type3=scalar_float eqn3="Gx-(sx*1.-1.)" > $@ hff=$@@@

# passive data only has 18 'shots'
${D}/gxgy-passive.H: ${SILVERLAKE}/gxgy.H
	Dd < $< ein=0 esize=4 > ${D}/tmpg.H
	Cat axis=1 ${D}/tmpg.H ${D}/tmpg.H ${D}/tmpg.H ${D}/tmpg.H ${D}/tmpg.H ${D}/tmpg.H ${D}/tmpg.H ${D}/tmpg.H ${D}/tmpg.H ${D}/tmpg.H \
	${D}/tmpg.H ${D}/tmpg.H ${D}/tmpg.H ${D}/tmpg.H ${D}/tmpg.H ${D}/tmpg.H ${D}/tmpg.H ${D}/tmpg.H | Transp > $@
	@Rm ${D}/tmpg.H

${D}/passive-vz2.H: ${D}/all-passive-vz.H ${D}/gxgy-passive.H
	cp $< ${D}/tmpvz.H
	echo "hff=-1" >> ${D}/tmpvz.H
	Cp ${D}/tmpvz.H $@
	Merge $<@@ ${D}/gxgy-passive.H axis=1 space=n > $@@@
	echo 'hdrkey16="Gx"    hdrtype16="scalar_float"   hdrfmt16="xdr_float"' >> $@@@
	echo 'hdrkey17="Gy"    hdrtype17="scalar_float"   hdrfmt17="xdr_float"' >> $@@@
	echo "hff=$@@@" >> $@

${D}/passive-vz.H: ${D}/passive-vz2.H
	Headermath < $< \
	key1=Sx type1=scalar_float eqn1="sx*1.-1." \
	key2=Sy type2=scalar_float eqn2="sx*0." \
	key3=Offsetx type3=scalar_float eqn3="Gx-(sx*1.-1.)" > $@ hff=$@@@

###############################################
# import magnetometer and rotation sensor data
#------------------------------------------------
# The data files in binary form. They are:
#
# mags.dat - the magnetometers at the three stations.  
# remote.dat - the remote site magnetometers
# rotation.dat - the rotation sensors at the three stations
#
# They are all saved as normal little-endian binary files and have values saved as float32’s.  
#
# You can map them into arrays with these dimensions (they were written in column major order)
#
# mags(12288,11,20) 
# remote(12288,5,20)
# rotation(12288,11,20) 
#
# First index:
# 12288 is 1024 Hz sampling * 12 seconds (i.e., 1 s before shot, 11 after)
#
# Second index:
# mags:  [time(s) trigger Bx1 By1 Bz1 Bx2 By2 Bz2 Bx3 By3 Bz3]
# rotation:  [time(s) trigger Rx1 Ry1 Rz1 Rx2 Ry2 Rz2 Rx3 Ry3 Rz3]
# remote:   [time(s) trigger BxR ByR BzR ]
#
# Third index:
# 20 is the number of shots 
#
# So each file has the trigger time series in the 2nd column. The time values are seconds on April 16 in GPS time.  
# The trigger cable for shot 20 got disconnected from the ZEN logger.
#
# Magnetic components are in units of Tesla. Rotation sensors are still in Volts.  All mag and rotation sensor data has been bandpass filtered to 5-50Hz.   
#
###############################################

${D}/mag-all.H: ${SILVERLAKE}/mags.dat
	swapbytes < $< in=float  > ${SCRATCH}/mag.H@
	echo 'n1=12288' > $@
	echo 'd1=.0009765625' >> $@
	echo 'o1=-1.' >> $@
	echo 'label1="time (sec)"' >> $@
	echo 'n2=11' >> $@
	echo 'd2=1'  >> $@
	echo 'o2=0'  >> $@
	echo 'label2="header word"' >> $@
	echo 'n3=20' >> $@
	echo 'd3=-5.'  >> $@
	echo 'o3=-5.'  >> $@
	echo 'label3="Shot position"' >> $@
	echo 'sets next in="${SCRATCH}/mag.H@"' >> $@
	echo 'data_format="xdr_float"' >> $@

${D}/remote-mag-all.H: ${SILVERLAKE}/remote.dat
	swapbytes < $< in=float  > ${SCRATCH}/remote-mag.H@
	echo 'n1=12288' > $@
	echo 'd1=.0009765625' >> $@
	echo 'o1=-1.' >> $@
	echo 'label1="time (sec)"' >> $@
	echo 'n2=5' >> $@
	echo 'd2=1'  >> $@
	echo 'o2=0'  >> $@
	echo 'label2="header word"' >> $@
	echo 'n3=20' >> $@
	echo 'd3=-5.'  >> $@
	echo 'o3=-5.'  >> $@
	echo 'label3="Shot position"' >> $@
	echo 'sets next in="${SCRATCH}/remote-mag.H@"' >> $@
	echo 'data_format="xdr_float"' >> $@

${D}/rotations-all.H: ${SILVERLAKE}/rotations.dat
	swapbytes < $< in=float  > ${SCRATCH}/rotations.H@
	echo 'n1=12288' > $@
	echo 'd1=.0009765625' >> $@
	echo 'o1=-1.' >> $@
	echo 'label1="time (sec)"' >> $@
	echo 'n2=11' >> $@
	echo 'd2=1'  >> $@
	echo 'o2=0'  >> $@
	echo 'label2="header word"' >> $@
	echo 'n3=20' >> $@
	echo 'd3=-5.'  >> $@
	echo 'o3=-5.'  >> $@
	echo 'label3="Shot position"' >> $@
	echo 'sets next in="${SCRATCH}/rotations.H@"' >> $@
	echo 'data_format="xdr_float"' >> $@

