# separate remote mag data to components
# According to Kerry Key, there is a polarity flip resulting from the way the Zonge magnetometer antennas were connected to the ZEN logger,
# therefore we multiply the data by -1.
${D}/remote-bx.H: ${D}/remote-mag.H
	Window3d < $< n3=1 f3=0 | ${Interp2seismic} | ${WIN1} | Scale rscale=-1. > $@

${D}/remote-by.H: ${D}/remote-mag.H
	Window3d < $< n3=1 f3=1 | ${Interp2seismic} | ${WIN1} | Scale rscale=-1. > $@

${D}/remote-bz.H: ${D}/remote-mag.H
	Window3d < $< n3=1 f3=2 | ${Interp2seismic} | ${WIN1} | Scale rscale=-1. > $@

# separate active seismic mag data to components and stations
# According to Kerry Key, there is a polarity flip resulting from the way the Zonge magnetometer antennas were connected to the ZEN logger,
# therefore we multiply the data by -1.
${D}/bx-sta: ${D}/mag.H
	Window3d < ${D}/mag.H n3=1 f3=0 | ${Interp2seismic} | ${WIN1} | Scale rscale=-1. > $@1.H
	Window3d < ${D}/mag.H n3=1 f3=3 | ${Interp2seismic} | ${WIN1} | Scale rscale=-1. > $@2.H
	Window3d < ${D}/mag.H n3=1 f3=6 | ${Interp2seismic} | ${WIN1} | Scale rscale=-1. > $@3.H
	
${D}/by-sta: ${D}/mag.H
	Window3d < ${D}/mag.H n3=1 f3=1 | ${Interp2seismic} | ${WIN1} | Scale rscale=-1. > $@1.H
	Window3d < ${D}/mag.H n3=1 f3=4 | ${Interp2seismic} | ${WIN1} | Scale rscale=-1. > $@2.H
	Window3d < ${D}/mag.H n3=1 f3=7 | ${Interp2seismic} | ${WIN1} | Scale rscale=-1. > $@3.H
	
${D}/bz-sta: ${D}/mag.H
	Window3d < ${D}/mag.H n3=1 f3=2 | ${Interp2seismic} | ${WIN1} | Scale rscale=-1. > $@1.H
	Window3d < ${D}/mag.H n3=1 f3=5 | ${Interp2seismic} | ${WIN1} | Scale rscale=-1. > $@2.H
	Window3d < ${D}/mag.H n3=1 f3=8 | ${Interp2seismic} | ${WIN1} | Scale rscale=-1. > $@3.H

# naively clean up mag data
${D}/clean-bx-sta%.H: ${D}/bx-sta%.H ${D}/remote-bx.H
	Add scale=1,-1 ${D}/bx-sta$*.H ${D}/remote-bx.H > $@
	
${D}/clean-by-sta%.H: ${D}/by-sta%.H ${D}/remote-by.H
	Add scale=1,-1 ${D}/by-sta$*.H ${D}/remote-by.H > $@

# Noise at remote station for Z component was stronger than signal because of instrument problems,
# therefore we do not subtract it from the data.
${D}/clean-bz-sta%.H: ${D}/bz-sta%.H ${D}/remote-bz.H
	#Add scale=1,-1 ${D}/bz-sta$*.H ${D}/remote-bz.H > $@
	Cp ${D}/bz-sta$*.H $@

# compare before/after cleaning
${R}/clean-b%: ${D}/b%-sta1.H ${D}/b%-sta2.H ${D}/b%-sta3.H ${D}/clean-b%-sta1.H ${D}/clean-b%-sta2.H ${D}/clean-b%-sta3.H
	Merge ${D}/b$*-sta1.H ${D}/clean-b$*-sta1.H axis=2 | ${BP1} | ${WIN1} | Balance | ${Wiggly} title="B$* before/after denoise at sta 1" out=$@-sta1.v > ${dn}
	Merge ${D}/b$*-sta2.H ${D}/clean-b$*-sta2.H axis=2 | ${BP1} | ${WIN1} | Balance | ${Wiggly} title="B$* before/after denoise at sta 2" out=$@-sta2.v > ${dn}
	Merge ${D}/b$*-sta3.H ${D}/clean-b$*-sta3.H axis=2 | ${BP1} | ${WIN1} | Balance | ${Wiggly} title="B$* before/after denoise at sta 3" out=$@-sta3.v > ${dn}
	Merge ${D}/b$*-sta1.H ${D}/clean-b$*-sta1.H axis=2 | ${BP1} | ${WIN1} | Balance | Spectra | Window max1=60 | Grey newclip=1 color=j title="B$* before/after denoise at sta 1" out=$@-sta1-f.v > ${dn}
	Merge ${D}/b$*-sta2.H ${D}/clean-b$*-sta2.H axis=2 | ${BP1} | ${WIN1} | Balance | Spectra | Window max1=60 | Grey newclip=1 color=j title="B$* before/after denoise at sta 2" out=$@-sta2-f.v > ${dn}
	Merge ${D}/b$*-sta3.H ${D}/clean-b$*-sta3.H axis=2 | ${BP1} | ${WIN1} | Balance | Spectra | Window max1=60 | Grey newclip=1 color=j title="B$* before/after denoise at sta 3" out=$@-sta3-f.v > ${dn}

magclean:
	#Rm ${D}/remote-bx.H ${D}/remote-by.H  ${D}/remote-bz.H
	make ${D}/bx-sta ${D}/by-sta ${D}/bz-sta
	make ${D}/clean-bx-sta1.H ${D}/clean-by-sta1.H ${D}/clean-bz-sta1.H
	make ${D}/clean-bx-sta2.H ${D}/clean-by-sta2.H ${D}/clean-bz-sta2.H
	make ${D}/clean-bx-sta3.H ${D}/clean-by-sta3.H ${D}/clean-bz-sta3.H
	make ${R}/mag-and-rot1 ${R}/rot1 ${R}/denoise-mag1 ${R}/mag1
	make ${R}/mag-and-rot2 ${R}/rot2 ${R}/denoise-mag2 ${R}/mag2
	make ${R}/mag-and-rot3 ${R}/rot3 ${R}/denoise-mag3 ${R}/mag3
	make ${R}/remote

# bandpass clean mag data.
${D}/bp-bx-sta%.H: ${D}/clean-bx-sta%.H
	${BP1} < $< > $@

${D}/bp-by-sta%.H: ${D}/clean-by-sta%.H
	${BP1} < $< > $@

${D}/bp-bz-sta%.H: ${D}/clean-bz-sta%.H
	${BP1} < $< > $@

# compare mag sections to rotation sections
${R}/mag-and-rot%: ${D}/ry-sta%-lshift.H ${D}/bp-by-sta%.H ${D}/rx-sta%-lshift.H ${D}/bp-bx-sta%.H ${D}/rz-sta%-lshift.H ${D}/bp-bz-sta%.H
	Merge ${D}/ry-sta$*-lshift.H ${D}/rx-sta$*-lshift.H ${D}/rz-sta$*-lshift.H axis=3 space=n | Scale rscale=1e+3 |\
	Grey newclip=1 titles="Ry:Rx:Rz" wantscalebar=y barlabel="mrad/s" bartype=h label1="Time(sec)" label2="Shot position" out=${R}/tmpr.v > ${dn}
	vppen < ${R}/tmpr.v out0=${R}/tmpry.v out1=${R}/tmprx.v out2=${R}/tmprz.v vpstyle=n > ${dn}

	Merge ${D}/bp-by-sta$*.H ${D}/bp-bx-sta$*.H ${D}/bp-bz-sta$*.H axis=3 space=n | Scale rscale=1e+9 |\
	Grey newclip=1 titles="By:Bx:Bz" wantscalebar=y barlabel="nanoTesla" bartype=h label1="Time(sec)" label2="Shot position" out=${R}/tmpb.v > ${dn}
	vppen < ${R}/tmpb.v out0=${R}/tmpby.v out1=${R}/tmpbx.v out2=${R}/tmpbz.v vpstyle=n > ${dn}

	vp_SideBySideAniso ${R}/tmpry.v ${R}/tmpbx.v ${R}/tmpbz.v > $@-y.v
	vp_SideBySideAniso ${R}/tmprx.v ${R}/tmpby.v ${R}/tmpbz.v > $@-x.v
	vp_SideBySideAniso ${R}/tmprz.v ${R}/tmpbx.v ${R}/tmpby.v > $@-z.v

	make ${R}/mag-and-rot$*-y.pdf
	make ${R}/mag-and-rot$*-x.pdf
	make ${R}/mag-and-rot$*-z.pdf
	@rm ${R}/tmp[br]*.v

GreyRB = bartype=v labelsz=6 label1="Time(sec)" label2="Shot position" # xll=1 xur=5 yll=1 yur=9 bar.xll=5 bar.xur=6 bar.yll=1 bar.yur=9

${R}/rot%: ${D}/ry-sta%-lshift.H ${D}/rx-sta%-lshift.H ${D}/rz-sta%-lshift.H
	Merge ${D}/ry-sta$*-lshift.H ${D}/rx-sta$*-lshift.H ${D}/rz-sta$*-lshift.H axis=3 space=n | Scale rscale=1e+3 |\
	Grey newclip=1 titles="Ry:Rx:Rz" wantscalebar=y barlabel="mrad/s" ${GreyRB} out=${R}/tmpr.v > ${dn}
	vppen < ${R}/tmpr.v out0=$@-ry.v out1=$@-rx.v out2=$@-rz.v vpstyle=n > ${dn}

	@rm ${R}/tmpr.v
	make ${R}/rot$*-rx.pdf ${R}/rot$*-ry.pdf ${R}/rot$*-rz.pdf

${R}/denoise-mag%:\
	${D}/by-sta%.H ${D}/bx-sta%.H ${D}/bz-sta%.H \
	${D}/remote-by.H ${D}/remote-bx.H ${D}/remote-bz.H \
	${D}/clean-by-sta%.H ${D}/clean-bx-sta%.H ${D}/clean-bz-sta%.H
	Scale rscale=0 < ${D}/clean-bz-sta$*.H > ${D}/tmpzero.H
	Merge axis=3 space=n ${D}/by-sta$*.H ${D}/bx-sta$*.H ${D}/bz-sta$*.H ${D}/remote-by.H ${D}/remote-bx.H ${D}/remote-bz.H ${D}/clean-by-sta$*.H ${D}/clean-bx-sta$*.H ${D}/tmpzero.H |\
	Scale rscale=1e+9 |\
	${BP1} |\
	Grey newclip=1 titles="By:Bx:Bz:Remote By:Remote Bx:Remote Bz:Denoised By:Denoised Bx: " wantscalebar=y barlabel="nanoTesla" ${GreyRB} out=${R}/tmpb.v > ${dn}
	vppen < ${R}/tmpb.v \
	out0=$@-by.v out1=$@-bx.v out2=$@-bz.v \
	out3=$@-rby.v out4=$@-rbx.v out5=$@-rbz.v \
	out6=$@-cby.v out7=$@-cbx.v out8=$@-cbz.v vpstyle=n > ${dn}

	@rm ${R}/tmpb.v
	make ${R}/denoise-mag$*-bx.pdf ${R}/denoise-mag$*-by.pdf ${R}/denoise-mag$*-bz.pdf
	make ${R}/denoise-mag$*-rbx.pdf ${R}/denoise-mag$*-rby.pdf ${R}/denoise-mag$*-rbz.pdf
	make ${R}/denoise-mag$*-cbx.pdf ${R}/denoise-mag$*-cby.pdf ${R}/denoise-mag$*-cbz.pdf

${R}/mag%: ${D}/bp-by-sta%.H ${D}/bp-bx-sta%.H ${D}/bp-bz-sta%.H
	Merge ${D}/bp-by-sta$*.H ${D}/bp-bx-sta$*.H ${D}/bp-bz-sta$*.H axis=3 space=n | Scale rscale=1e+9 |\
	Grey newclip=1 titles="By - By remote:Bx - Bx remote:Bz" wantscalebar=y barlabel="nanoTesla" ${GreyRB} out=${R}/tmpb.v > ${dn}
	vppen < ${R}/tmpb.v out0=$@-by.v out1=$@-bx.v out2=$@-bz.v vpstyle=n > ${dn}

	@rm ${R}/tmpb.v
	make ${R}/mag$*-bx.pdf ${R}/mag$*-by.pdf ${R}/mag$*-bz.pdf

${R}/remote: ${D}/remote-by.H ${D}/remote-bx.H ${D}/remote-bz.H
	Merge $^ axis=3 space=n | Scale rscale=1e+9 |\
	Grey newclip=1 titles="By remote:Bx remote:Bz remote" wantscalebar=y barlabel="nanoTesla" ${GreyRB} labelsz=5 out=${R}/tmpb.v > ${dn}
	vppen < ${R}/tmpb.v out0=$@-by.v out1=$@-bx.v out2=$@-bz.v vpstyle=n > ${dn}

	@rm ${R}/tmpb.v
	make ${R}/remote-bx.pdf ${R}/remote-by.pdf ${R}/remote-bz.pdf


