###############################################################
# use quaternions to go from magnetic deviations to rotations.
# Need to add ambient field values to X Y and Z mag components
###############################################################

# North, East and vertical magnetic intensity in Silver Lake on the day of the survey (2015-04-16). Altitude=763m.
# source: British Geological Survey World Magnetic Model calculator
Nintensity=23236
Eintensity=4945
Zintensity=41942
TOTintensity=48202

# declination is 12.015 degrees
Declination=0.2097013096

# our X component was oriented to 120 degrees
Xorient = 2.0943951023

# our Y component was oriented to 30 degrees
Yorient = 0.5235987755

# angle difference between our horizontal magnetic sensors and the Earth's field
#Theta = $(shell echo $(Yorient)-$(Declination) | bc -l)
Theta = $(Yorient)

# magnetic field intensity in our survey's orientation
Xintensity = $(shell echo $(Eintensity)*c\(-$(Theta)\)-$(Nintensity)*s\(-$(Theta)\) | bc -l)
Yintensity = $(shell echo $(Eintensity)*s\(-$(Theta)\)+$(Nintensity)*c\(-$(Theta)\) | bc -l)

showmag:
	@echo $(Xintensity)
	@echo $(Yintensity)
	@echo $(Zintensity)

# time sampling
dt = 0.001
idt = $(shell echo 1./$(dt) | bc -l | awk '{printf "%f", $$0}')

${D}/bz-val%.H: ${D}/bp-bz-sta%.H
	Scale < ${D}/bp-bz-sta$*.H rscale=1e+9 | Math file1=in exp='file1+${Zintensity}' > $@

${D}/bz-fromxy-val%.H: ${D}/bx-val%.H ${D}/by-val%.H
	Math file1=${D}/bx-val$*.H file2=${D}/by-val$*.H exp='@SQRT(${TOTintensity}^2-file1^2-file2^2)' > $@

${D}/bp-bz-fromxy-sta%.H: ${D}/bz-fromxy-val%.H
	Math file1=$< exp='file1-${Zintensity}' | Scale rscale=1e-9 > $@

${D}/bx-val%.H ${D}/by-val%.H: ${D}/bp-bx-sta%.H ${D}/bp-by-sta%.H ${D}/bp-bz-sta%.H
	Scale < ${D}/bp-bx-sta$*.H rscale=1e+9 | Math file1=in exp='file1+${Xintensity}' > ${D}/bx-val$*.H
	Scale < ${D}/bp-by-sta$*.H rscale=1e+9 | Math file1=in exp='file1+${Yintensity}' > ${D}/by-val$*.H


# get rotation angle, axis of rotation and quaternion representation
${D}/theta%.H ${D}/uvec%.H ${D}/quatrot%.H ${D}/euler%.H: ${D}/bx-val%.H ${D}/by-val%.H ${D}/bz-val%.H ${B}/Rtheta_vector.x
	${B}/Rtheta_vector.x X=${D}/bx-val$*.H Y=${D}/by-val$*.H Z=${D}/bz-val$*.H \
	theta=${D}/theta$*.H uvec=${D}/uvec$*.H qout=${D}/tmpq.H euler=${D}/euler$*.H \
	jt=10 eps=1e-30 > ${dn}
	Transp < ${D}/tmpq.H plane=12 > ${D}/quatrot$*.H
	#@Rm ${D}/tmpq.H

# The vector part of the quaternion.
${D}/qrx-mag%.H ${D}/qry-mag%.H ${D}/qrz-mag%.H: ${D}/quatrot%.H
	Window3d < ${D}/quatrot$*.H n2=1 f2=1 > ${D}/qrx-mag$*.H
	Window3d < ${D}/quatrot$*.H n2=1 f2=2 > ${D}/qry-mag$*.H
	Window3d < ${D}/quatrot$*.H n2=1 f2=3 > ${D}/qrz-mag$*.H

# Window out rotations and apply first time derivative to get rotation-rates.
${D}/rx-mag%.H ${D}/ry-mag%.H ${D}/rz-mag%.H ${D}/Rx-mag%.H ${D}/Ry-mag%.H ${D}/Rz-mag%.H: ${D}/euler%.H ${B}/firstderiv.x

	Window3d < ${D}/euler$*.H n2=1 f2=0 | ${BP1} > ${D}/Rx-mag$*.H
	Window3d < ${D}/euler$*.H n2=1 f2=1 | ${BP1} > ${D}/Ry-mag$*.H
	Window3d < ${D}/euler$*.H n2=1 f2=2 | ${BP1} > ${D}/Rz-mag$*.H

	${B}/firstderiv.x < ${D}/Rx-mag$*.H | ${BP1} > ${D}/rx-mag$*.H
	${B}/firstderiv.x < ${D}/Ry-mag$*.H | ${BP1} > ${D}/ry-mag$*.H
	${B}/firstderiv.x < ${D}/Rz-mag$*.H | ${BP1} > ${D}/rz-mag$*.H

# there is a lot of low frequency added to the data after the conversion to quaternions.
# I need to bandpass it to the same range as the original data was.
Greycompmag = Grey gainpanel=e label1="Time(sec)" label2="Shot position (m)" titlesz=0 labelsz=4 wantscalebar=y barlabel="mrad/sec" # xll=1 xur=6 yll=0 yur=4 bar.xll=6 bar.xur=7 bar.yll=0 bar.yur=4
#Grey2 = Grey newclip=1 label1="Time(sec)" label2="Shot position (m)" titlesz=0 labelsz=5 wantscalebar=y barlabel="mrad/sec" xll=1 xur=11 yll=0 yur=6 bar.xll=11 bar.xur=12 bar.yll=0 bar.yur=6
Grey2 = Grey newclip=1 label1="Time(sec)" label2="Shot position (m)" titlesz=0 labelsz=8 wantscalebar=y barlabel="mrad/sec" xll=1 xur=7 yll=0 yur=9 bar.xll=7 bar.xur=8 bar.yll=0 bar.yur=9
Grey3 = Grey newclip=1 label1="Time(sec)" label2="Shot position (m)" titlesz=14 labelsz=7 wantscalebar=y barlabel="mrad/sec"

#===============================
# compare rotations with Grey
#===============================
#${R}/comp-rx%: ${D}/rx-mag%.H ${D}/rx-sta%-lshift.H ${D}/vz-rx-sta%.H
#	${BP1} < ${D}/rx-mag$*.H > ${D}/rx-mag$*-bp.H
#	Merge axis=3 space=n ${D}/rx-mag$*-bp.H ${D}/rx-sta$*-lshift.H ${D}/vz-rx-sta$*.H |\
#	Scale rscale=1e+3 |\
#	${Greycompmag} titles="Rx from magnetometers:Rx rotation sensor:Rx from geophones" out=${R}/tmpx.v > ${dn}
#	vppen < ${R}/tmpx.v out0=$@-mag.v out1=$@-rsn.v out2=$@-geo.v vpstyle=n > ${dn}
#	make ${R}/comp-rx$*-mag.pdf ${R}/comp-rx$*-rsn.pdf ${R}/comp-rx$*-geo.pdf
#
#${R}/comp-ry%: ${D}/ry-mag%.H ${D}/ry-sta%-lshift.H ${D}/vz-ry-sta%.H
#	${BP1} < ${D}/ry-mag$*.H > ${D}/ry-mag$*-bp.H
#	Merge axis=3 space=n ${D}/ry-mag$*-bp.H ${D}/ry-sta$*-lshift.H ${D}/vz-ry-sta$*.H |\
#	Scale rscale=1e+3 |\
#	${Greycompmag} titles="Ry from magnetometers:Ry rotation sensor:Ry from geophones" out=${R}/tmpy.v > ${dn}
#	vppen < ${R}/tmpy.v out0=$@-mag.v out1=$@-rsn.v out2=$@-geo.v vpstyle=n > ${dn}
#	make ${R}/comp-ry$*-mag.pdf ${R}/comp-ry$*-rsn.pdf ${R}/comp-ry$*-geo.pdf
#
#${R}/comp-rz%: ${D}/rz-mag%.H ${D}/rz-sta%-lshift.H
#	${BP1} < ${D}/rz-mag$*.H > ${D}/rz-mag$*-bp.H
#	Scale rscale=0 < ${D}/rz-mag$*.H > ${D}/zero.H
#	Merge axis=3 space=n ${D}/rz-mag$*-bp.H ${D}/rz-sta$*-lshift.H ${D}/zero.H |\
#	Scale rscale=1e+3 |\
#	${Greycompmag} titles="Rz from magnetometers:Rz rotation sensor:Rz from geophones" out=${R}/tmpz.v > ${dn}
#	vppen < ${R}/tmpz.v out0=$@-mag.v out1=$@-rsn.v out2=$@-geo.v vpstyle=n > ${dn}
#	make ${R}/comp-rz$*-mag.pdf ${R}/comp-rz$*-rsn.pdf ${R}/comp-rz$*-geo.pdf


#===============================
# compare rotations with Wiggle
#===============================
${R}/comp-rx%-mag2rsn.v: ${D}/rx-sta%-lshift.H ${D}/rx-mag%.H
	Merge $^ axis=3 space=n | Window min1=0.2 f2=5 | ${Wiggly} pclip=97 poly=y plotcol=${whi} plotfat=4 title="Rsensor roll (red) vs Mag roll (blue)" out=${R}/tmpx1.v > ${dn}
	Merge $^ axis=3 space=n | Window min1=0.2 f2=5 | ${Wiggly} pclip=97 poly=n plotcol=${cya} plotfat=4 title="Rsensor roll (red) vs Mag roll (blue)" out=${R}/tmpx2.v > ${dn}
	vppen < ${R}/tmpx1.v vpstyle=n out0=${R}/tmpx3.v out1=${dn} > ${dn}
	vppen < ${R}/tmpx2.v vpstyle=n out0=${dn}        out1=${R}/tmpx4.v  > ${dn}
	vp_Overlay ${R}/tmpx3.v ${R}/tmpx4.v > $@
	@rm ${R}/tmpx[1234].v

${R}/comp-ry%-mag2rsn.v: ${D}/ry-sta%-lshift.H ${D}/ry-mag%.H
	Merge $^ axis=3 space=n | Window min1=0.2 f2=5 | ${Wiggly} pclip=97 poly=y plotcol=${whi} plotfat=4 title="Rsensor pitch (red) vs Mag pitch (blue)" out=${R}/tmpy1.v > ${dn}
	Merge $^ axis=3 space=n | Window min1=0.2 f2=5 | ${Wiggly} pclip=97 poly=n plotcol=${cya} plotfat=4 title="Rsensor pitch (red) vs Mag pitch (blue)" out=${R}/tmpy2.v > ${dn}
	vppen < ${R}/tmpy1.v vpstyle=n out0=${R}/tmpy3.v out1=${dn} > ${dn}
	vppen < ${R}/tmpy2.v vpstyle=n out0=${dn}        out1=${R}/tmpy4.v  > ${dn}
	vp_Overlay ${R}/tmpy3.v ${R}/tmpy4.v > $@
	@rm ${R}/tmpy[1234].v

${R}/comp-rz%-mag2rsn.v: ${D}/rz-sta%-lshift.H ${D}/rz-mag%.H
	Merge $^ axis=3 space=n | Window min1=0.2 f2=5 | ${Wiggly} pclip=97 poly=y plotcol=${whi} plotfat=4 title="Rsensor yaw (red) vs Mag yaw (blue)" out=${R}/tmpz1.v > ${dn}
	Merge $^ axis=3 space=n | Window min1=0.2 f2=5 | ${Wiggly} pclip=97 poly=n plotcol=${cya} plotfat=4 title="Rsensor yaw (red) vs Mag yaw (blue)" out=${R}/tmpz2.v > ${dn}
	vppen < ${R}/tmpz1.v vpstyle=n out0=${R}/tmpz3.v out1=${dn} > ${dn}
	vppen < ${R}/tmpz2.v vpstyle=n out0=${dn}        out1=${R}/tmpz4.v  > ${dn}
	vp_Overlay ${R}/tmpz3.v ${R}/tmpz4.v > $@
	@rm ${R}/tmpz[1234].v


${R}/vz-%: ${D}/vz-sta%.H
	Scale < $< rscale=1e+3 |\
	${Grey3} title="Vertical Geophone" barlabel="mm/s" out=$@.v > ${dn}
	vp_annotate < $@.v batch=y text=${R}/NR/$(@F).txt > $@-ann.v
	make $@-ann.pdf

${R}/rsn-%: ${D}/rx-sta%-lshift.H ${D}/ry-sta%-lshift.H ${D}/rz-sta%-lshift.H
	Merge axis=3 space=n $^ | Scale rscale=1e+3 |\
	${Grey3} titles="Rotation sensor roll:Rotation sensor pitch:Rotation sensor yaw" out=${R}/tmprsn.v > ${dn}
	vppen < ${R}/tmprsn.v out0=$@rx.v out1=$@ry.v out2=$@rz.v vpstyle=n > ${dn}
	make $@rx.pdf $@ry.pdf $@rz.pdf

${R}/geodiff-%: ${D}/vz-rx-sta%.H ${D}/vz-ry-sta%.H
	Scale rscale=0 < ${D}/vz-rx-sta$*.H > ${D}/zero.H
	Merge axis=3 space=n $^ ${D}/zero.H | Scale rscale=1e+3 |\
	${Grey3} titles="Geophone-diff roll:Geophone-diff pitch:Geophone-diff yaw" out=${R}/tmpgeo.v > ${dn}
	vppen < ${R}/tmpgeo.v out0=$@rx.v out1=$@ry.v out2=$@rz.v vpstyle=n > ${dn}
	make $@rx.pdf $@ry.pdf $@rz.pdf

${R}/mag-%: ${D}/rx-mag%.H ${D}/ry-mag%.H ${D}/rz-mag%.H
	Merge axis=3 space=n $^ | Scale rscale=1e+3 |\
	${Grey3} titles="Mag roll:Mag pitch:Mag yaw" out=${R}/tmpmag.v > ${dn}
	vppen < ${R}/tmpmag.v out0=$@rx.v out1=$@ry.v out2=$@rz.v vpstyle=n > ${dn}
	make $@rx.pdf $@ry.pdf $@rz.pdf

${R}/gcomp-%: \
	${D}/ry-mag%.H ${D}/ry-sta%-lshift.H ${D}/vz-ry-sta%.H \
	${D}/rx-mag%.H ${D}/rx-sta%-lshift.H ${D}/vz-rx-sta%.H \
	${D}/rz-mag%.H ${D}/rz-sta%-lshift.H
	Scale < $< rscale=0. > ${D}/vz-rz-sta$*.H
	Merge axis=3 space=n $^ ${D}/vz-rz-sta$*.H | Scale rscale=1e+3 |\
	${Grey3} titles="Magnetic pitch:Rotation sensor pitch:Geophone-diff pitch:\
Magnetic roll:Rotation sensor roll:Geophone-diff roll:\
Magnetic yaw:Rotation sensor yaw:Geophone-diff yaw" \
	out=${R}/tmpr.v > ${dn}
	vppen < ${R}/tmpr.v \
	out0=$@ry-mag.v out1=$@ry-rsn.v out2=$@ry-geo.v \
	out3=$@rx-mag.v out4=$@rx-rsn.v out5=$@rx-geo.v \
	out6=$@rz-mag.v out7=$@rz-rsn.v out8=$@rz-geo.v \
	vpstyle=n > ${dn}
	make $@ry-mag.pdf $@ry-rsn.pdf $@ry-geo.pdf $@rx-mag.pdf $@rx-rsn.pdf $@rx-geo.pdf $@rz-mag.pdf $@rz-rsn.pdf $@rz-geo.pdf
	@rm ${R}/tmpr.v

# LMO + stack of Magnetic data vs. rotation sensor data
${D}/r%-mag1-tmp.H: ${D}/r%-mag1.H
	Cp $< $@
	echo "o2=-5" >> $@
	echo "d2=5" >> $@

${D}/r%-mag2-tmp.H: ${D}/r%-mag2.H
	Cp $< $@
	echo "o2=-10" >> $@
	echo "d2=5" >> $@

${D}/r%-mag3-tmp.H: ${D}/r%-mag3.H
	Cp $< $@
	echo "o2=-15" >> $@
	echo "d2=5" >> $@

${D}/r%-sta1-tmp.H: ${D}/r%-sta1-lshift.H
	Cp $< $@
	echo "o2=-5" >> $@
	echo "d2=5" >> $@

${D}/r%-sta2-tmp.H: ${D}/r%-sta2-lshift.H
	Cp $< $@
	echo "o2=-10" >> $@
	echo "d2=5" >> $@

${D}/r%-sta3-tmp.H: ${D}/r%-sta3-lshift.H
	Cp $< $@
	echo "o2=-15" >> $@
	echo "d2=5" >> $@

${D}/r%-stck.H: ${D}/r%-tmp.H
	Stretch < $< rule=lmo2 vel=135 | Window f2=0 | Stack normalize=y | Window max1=0.32 > $@

# compare rotations to magnetic rotations for LMO+stacked receiver gather
GraphMag2rsn = Graph dash=0,4 plotfat=7 plotcol=${whi},${gre} legend=y label1="time(sec)" label2="mrad/sec" min2=-0.15 max2=0.15
${R}/gcomptrace-%mag2rsn: \
	${D}/rx-sta%-stck.H ${D}/rx-mag%-stck.H ${D}/ry-sta%-stck.H \
	${D}/ry-mag%-stck.H ${D}/rz-sta%-stck.H ${D}/rz-mag%-stck.H
	Merge axis=2 space=n ${D}/rx-sta$*-stck.H ${D}/rx-mag$*-stck.H | Scale rscale=1e+3 | ${GraphMag2rsn} curvelabel="roll rsense:roll mag" out=$@-rx.v > ${dn}
	Merge axis=2 space=n ${D}/ry-sta$*-stck.H ${D}/ry-mag$*-stck.H | Scale rscale=1e+3 | ${GraphMag2rsn} curvelabel="pitch rsense:pitch mag" out=$@-ry.v > ${dn}
	Merge axis=2 space=n ${D}/rz-sta$*-stck.H ${D}/rz-mag$*-stck.H | Scale rscale=1e+3 | ${GraphMag2rsn} curvelabel="yaw rsense:yaw mag" out=$@-rz.v > ${dn}
	make $@-rx.pdf $@-ry.pdf $@-rz.pdf

${R}/gcomptrace2-%mag2rsn: \
	${D}/rx-sta%-stck.H ${D}/rx-mag%-stck.H ${D}/ry-sta%-stck.H \
	${D}/ry-mag%-stck.H ${D}/rz-sta%-stck.H ${D}/rz-mag%-stck.H
	Merge axis=2 space=n ${D}/rx-sta$*-stck.H ${D}/rx-mag$*-stck.H ${D}/ry-sta$*-stck.H ${D}/ry-mag$*-stck.H ${D}/rz-sta$*-stck.H ${D}/rz-mag$*-stck.H |\
	Scale rscale=1e+3 |\
	Window min1=0.05 max1=0.2 |\
	Graph dash=0,4,0,4,0,4 plotfat=7 plotcol=${yel},${yel},${gre},${gre},${whi},${whi} legend=y curvelabel="roll:roll-mag:pitch:pitch-mag:yaw:yaw-mag" title="LMO+stack of ground-roll" label1="time(sec)" label2="mrad/sec" out=$@.v > ${dn}
	make $@.pdf

${R}/gcomptrace3-%mag2rsn: ${D}/rx-sta%-lshift.H ${D}/rx-mag%.H ${D}/ry-sta%-lshift.H ${D}/ry-mag%.H ${D}/rz-sta%-lshift.H ${D}/rz-mag%.H
	Merge axis=3 space=n ${D}/rx-sta$*-lshift.H ${D}/rx-mag$*.H ${D}/ry-sta$*-lshift.H ${D}/ry-mag$*.H ${D}/rz-sta$*-lshift.H ${D}/rz-mag$*.H |\
	Scale rscale=1e+3 |\
	Window3d min2=-65 n2=1 min1=0.47 max1=0.62 |\
	Graph dash=0,4,0,4,0,4 plotfat=7 plotcol=${yel},${yel},${gre},${gre},${whi},${whi} legend=y curvelabel="roll:roll-mag:pitch:pitch-mag:yaw:yaw-mag" title="ground-roll at offset 65 m" label1="time(sec)" label2="mrad/sec" out=$@.v > ${dn}
	make $@.pdf

mag2rot:
	#Rm   ${D}/b[xyz]-val1.H ${D}/theta1.H ${D}/qr[xyz]-mag1.H ${D}/r[xyz]-mag1.H
	#Rm   ${D}/b[xyz]-val2.H ${D}/theta2.H ${D}/qr[xyz]-mag2.H ${D}/r[xyz]-mag2.H
	#Rm   ${D}/b[xyz]-val3.H ${D}/theta3.H ${D}/qr[xyz]-mag3.H ${D}/r[xyz]-mag3.H
	make ${D}/by-val1.H ${D}/bz-val1.H ${D}/theta1.H ${D}/qry-mag1.H ${D}/ry-mag1.H
	make ${D}/by-val2.H ${D}/theta2.H ${D}/qry-mag2.H ${D}/ry-mag2.H
	make ${D}/by-val3.H ${D}/theta3.H ${D}/qry-mag3.H ${D}/ry-mag3.H
	make ${R}/comp-rx1-mag2rsn.v ${R}/comp-ry1-mag2rsn.v ${R}/comp-rz1-mag2rsn.v
	make ${R}/comp-rx2-mag2rsn.v ${R}/comp-ry2-mag2rsn.v ${R}/comp-rz2-mag2rsn.v
	make ${R}/comp-rx3-mag2rsn.v ${R}/comp-ry3-mag2rsn.v ${R}/comp-rz3-mag2rsn.v
	make ${R}/comp-rx1-mag2rsn.pdf ${R}/comp-ry1-mag2rsn.pdf ${R}/comp-rz1-mag2rsn.pdf
	make ${R}/comp-rx2-mag2rsn.pdf ${R}/comp-ry2-mag2rsn.pdf ${R}/comp-rz2-mag2rsn.pdf
	make ${R}/comp-rx3-mag2rsn.pdf ${R}/comp-ry3-mag2rsn.pdf ${R}/comp-rz3-mag2rsn.pdf
	make ${R}/vz-1 ${R}/mag-1 ${R}/rsn-1 ${R}/geodiff-1 ${R}/gcomp-1 ${R}/gcomptrace-1mag2rsn
	make ${R}/vz-2 ${R}/mag-2 ${R}/rsn-2 ${R}/geodiff-2 ${R}/gcomp-2 ${R}/gcomptrace-2mag2rsn
	make ${R}/vz-3 ${R}/mag-3 ${R}/rsn-3 ${R}/geodiff-3 ${R}/gcomp-3 ${R}/gcomptrace-3mag2rsn


# phase difference between rotation sensors and magnetometer rotations
#${D}/ry-mag%-shift.H ${D}/ry-mag-lphd%.H ${D}/ry-mag-sphd%.H: ${D}/ry-sta%-lshift.H ${D}/ry-mag%.H ${B}/phasematch.x ${P}/desig-mag-phase.P
#	${B}/phasematch.x file1=${D}/ry-mag$*.H file2=${D}/ry-sta$*-lshift.H par=${P}/desig-mag-phase.P tape1=0.05 \
#	amp=${D}/ry-mag-amp$*.H unrap=${D}/ry-mag-unrap$*.H sphased=${D}/ry-mag-sphd$*.H lphased=${D}/ry-mag-lphd$*.H > ${D}/ry-mag$*-shift.H

# phase difference between rotation sensors and magnetometer rotations
${D}/ry-mag-lphd%.H ${D}/ry-mag-sphd%.H: ${D}/ry-mag%.H ${D}/ry-sta%-lshift.H ${B}/phasematch-cc.x ${P}/desig-mag-phase.P
	${B}/phasematch-cc.x file1=${D}/ry-mag$*.H file2=${D}/ry-sta$*-lshift.H par=${P}/desig-mag-phase.P \
	amp=${D}/ry-mag-amp$*.H phased=${D}/ry-mag-phd$*.H sphased=${D}/ry-mag-sphd$*.H lphased=${D}/ry-mag-lphd$*.H > ${dn}

${D}/rx-mag-lphd%.H ${D}/rx-mag-sphd%.H: ${D}/rx-mag%.H ${D}/rx-sta%-lshift.H ${B}/phasematch-cc.x ${P}/desig-mag-phase.P
	${B}/phasematch-cc.x file1=${D}/rx-mag$*.H file2=${D}/rx-sta$*-lshift.H par=${P}/desig-mag-phase.P \
	amp=${D}/rx-mag-amp$*.H phased=${D}/rx-mag-phd$*.H sphased=${D}/rx-mag-sphd$*.H lphased=${D}/rx-mag-lphd$*.H > ${dn}

${D}/rz-mag-lphd%.H ${D}/rz-mag-sphd%.H: ${D}/rz-mag%.H ${D}/rz-sta%-lshift.H ${B}/phasematch-cc.x ${P}/desig-mag-phase.P
	${B}/phasematch-cc.x file1=${D}/rz-mag$*.H file2=${D}/rz-sta$*-lshift.H par=${P}/desig-mag-phase.P \
	amp=${D}/rz-mag-amp$*.H phased=${D}/rz-mag-phd$*.H sphased=${D}/rz-mag-sphd$*.H lphased=${D}/rz-mag-lphd$*.H > ${dn}

${D}/ry-mag%-lshift.H: ${D}/ry-mag%.H ${D}/ry-mag-lphd%.H ${B}/phaseshift.x
	${B}/phaseshift.x < $< phase=${D}/ry-mag-lphd$*.H > $@

${D}/rx-mag%-lshift.H: ${D}/rx-mag%.H ${D}/rx-mag-lphd%.H ${B}/phaseshift.x
	${B}/phaseshift.x < $< phase=${D}/rx-mag-lphd$*.H > $@

${D}/rz-mag%-lshift.H: ${D}/rz-mag%.H ${D}/rz-mag-lphd%.H ${B}/phaseshift.x
	${B}/phaseshift.x < $< phase=${D}/rz-mag-lphd$*.H > $@

#======================
# phase shift figures
#======================
GraphPS = Graph min2=-180 max2=180 o2num=-180 d2num=45 plotfat=8,8,8 legend=y legendpos=10.8,1.2 curvelabel="station 1:station 2:station 3" label1="frequency(Hz)" label2="Phase lag (degrees)" titlesz=13 labelsz=8 legendsz=10

# phase shift of pitch
${R}/ry-mag-phasediffs.v: ${D}/ry-mag-sphd1.H ${D}/ry-mag-sphd2.H ${D}/ry-mag-sphd3.H
	Merge ${D}/ry-mag-sphd1.H ${D}/ry-mag-sphd2.H ${D}/ry-mag-sphd3.H axis=2 space=n | Window min1=3 max1=30 |\
	${GraphPS} title="Pitch phase lags" out=$@ > ${dn}

# phase shift of roll
${R}/rx-mag-phasediffs.v: ${D}/rx-mag-sphd1.H ${D}/rx-mag-sphd2.H ${D}/rx-mag-sphd3.H
	Merge ${D}/rx-mag-sphd1.H ${D}/rx-mag-sphd2.H ${D}/rx-mag-sphd3.H axis=2 space=n | Window min1=3 max1=30 |\
	${GraphPS} title="Roll phase lags" out=$@ > ${dn}

# phase shift of yaw
${R}/rz-mag-phasediffs.v: ${D}/rz-mag-sphd1.H ${D}/rz-mag-sphd2.H ${D}/rz-mag-sphd3.H
	Merge ${D}/rz-mag-sphd1.H ${D}/rz-mag-sphd2.H ${D}/rz-mag-sphd3.H axis=2 space=n | Window min1=3 max1=30 |\
	${GraphPS} title="Yaw phase lags" out=$@ > ${dn}

# correlation lags of rotation sensors and magnetometer rotations - pitch
${R}/clags-ry-mag-sta%: ${D}/ry-mag%.H ${D}/ry-sta%-lshift.H ${D}/ry-mag%-lshift.H ${B}/lagtrace.x
	${B}/lagtrace.x file1=${D}/ry-mag$*.H        file2=${D}/ry-sta$*-lshift.H corr=${D}/$(@F).H > ${dn}
	Balance < ${D}/$(@F).H | Window3d min1=-0.25 max1=0.25 | ${Wiggly} label1="pitch correlation lag (sec)" title="station $*" out=$@.v > ${dn}

# correlation lags of rotation sensors and magnetometer rotations - roll
${R}/clags-rx-mag-sta%: ${D}/rx-mag%.H ${D}/rx-sta%-lshift.H ${D}/rx-mag%-lshift.H ${B}/lagtrace.x
	${B}/lagtrace.x file1=${D}/rx-mag$*.H        file2=${D}/rx-sta$*-lshift.H corr=${D}/$(@F).H > ${dn}
	Balance < ${D}/$(@F).H | Window3d min1=-0.25 max1=0.25 | ${Wiggly} label1="roll correlation lag (sec)" title="station $*" out=$@.v > ${dn}

# correlation lags of rotation sensors and magnetometer rotations - yaw
${R}/clags-rz-mag-sta%: ${D}/rz-mag%.H ${D}/rz-sta%-lshift.H ${D}/rz-mag%-lshift.H ${B}/lagtrace.x
	${B}/lagtrace.x file1=${D}/rz-mag$*.H        file2=${D}/rz-sta$*-lshift.H corr=${D}/$(@F).H > ${dn}
	Balance < ${D}/$(@F).H | Window3d min1=-0.25 max1=0.25 | ${Wiggly} label1="yaw correlation lag (sec)" title="station $*" out=$@.v > ${dn}

magphaseshift:
	#Rm ${D}/ry-mag-[sl]phd[123].H ${D}/rx-mag-[sl]phd[123].H ${D}/rz-mag-[sl]phd[123].H
	#rm ${R}/ry-mag-phasediffs.v ${R}/rx-mag-phasediffs.v ${R}/rz-mag-phasediffs.v
	make ${R}/ry-mag-phasediffs.v ${R}/rx-mag-phasediffs.v ${R}/rz-mag-phasediffs.v
	#make ${R}/clags-ry-mag-sta1 ${R}/clags-ry-mag-sta2 ${R}/clags-ry-mag-sta3
	#make ${R}/clags-rx-mag-sta1 ${R}/clags-rx-mag-sta2 ${R}/clags-rx-mag-sta3
	#make ${R}/clags-rz-mag-sta1 ${R}/clags-rz-mag-sta2 ${R}/clags-rz-mag-sta3

	make ${R}/rx-mag-phasediffs.pdf ${R}/ry-mag-phasediffs.pdf ${R}/rz-mag-phasediffs.pdf

