#========================
# convert rotation data to magnetic projections (forward modeling)
# and then back again to rotations (adjoint)
#========================

Xintensity_tesla = $(shell echo $(Xintensity)*10^-9 | bc -l)
Yintensity_tesla = $(shell echo $(Yintensity)*10^-9 | bc -l)
Zintensity_tesla = $(shell echo $(Zintensity)*10^-9 | bc -l)

# integrate rotation-rate to get rotations
${D}/Rx-sta%-lshift.H ${D}/Ry-sta%-lshift.H ${D}/Rz-sta%-lshift.H: ${B}/integ.x \
	${D}/rx-sta%-lshift.H ${D}/ry-sta%-lshift.H ${D}/rz-sta%-lshift.H

	${B}/integ.x < ${D}/rx-sta$*-lshift.H | ${BP1} > ${D}/Rx-sta$*-lshift.H
	${B}/integ.x < ${D}/ry-sta$*-lshift.H | ${BP1} > ${D}/Ry-sta$*-lshift.H
	${B}/integ.x < ${D}/rz-sta$*-lshift.H | ${BP1} > ${D}/Rz-sta$*-lshift.H

# apply forward modeling of magnetic projections from magnetic rotations
${D}/for-bx%.H ${D}/for-by%.H ${D}/for-bz%.H: ${B}/euler_rot.x \
	${D}/Rx-mag%.H ${D}/Ry-mag%.H ${D}/Rz-mag%.H

	${B}/euler_rot.x rx=${D}/Rx-mag$*.H ry=${D}/Ry-mag$*.H rz=${D}/Rz-mag$*.H \
	bx=${D}/for-bx$*.H by=${D}/for-by$*.H bz=${D}/for-bz$*.H \
	abx=$(Xintensity_tesla) aby=$(Yintensity_tesla) abz=$(Zintensity_tesla) > ${dn}

# apply forward modeling of magnetic projections from rotations sensor data
${D}/for-brx%.H ${D}/for-bry%.H ${D}/for-brz%.H: ${B}/euler_rot.x \
	${D}/Rx-sta%-lshift.H ${D}/Ry-sta%-lshift.H ${D}/Rz-sta%-lshift.H

	${B}/euler_rot.x rx=${D}/Rx-sta$*-lshift.H ry=${D}/Ry-sta$*-lshift.H rz=${D}/Rz-sta$*-lshift.H \
	bx=${D}/for-brx$*.H by=${D}/for-bry$*.H bz=${D}/for-brz$*.H \
	abx=$(Xintensity_tesla) aby=$(Yintensity_tesla) abz=$(Zintensity_tesla) > ${dn}

# compare forward modeled magnetic projections with observed projections using wiggle
${R}/for-comp-bx%.v: ${D}/bp-bx-sta%.H ${D}/for-bx%.H
	Merge $^ axis=3 space=n | Window min1=0.2 f2=5 | ${Wiggly} pclip=97 poly=y plotcol=${whi} plotfat=4 title="Bx observed (red) vs Bx modeled (blue)" out=${R}/tmpx1.v > ${dn}
	Merge $^ axis=3 space=n | Window min1=0.2 f2=5 | ${Wiggly} pclip=97 poly=n plotcol=${cya} plotfat=5 title="Bx observed (red) vs Bx modeled (blue)" out=${R}/tmpx2.v > ${dn}
	vppen < ${R}/tmpx1.v vpstyle=n out0=${R}/tmpx3.v out1=${dn} > ${dn}
	vppen < ${R}/tmpx2.v vpstyle=n out0=${dn}        out1=${R}/tmpx4.v  > ${dn}
	vp_Overlay ${R}/tmpx3.v ${R}/tmpx4.v > $@
	@rm ${R}/tmpx[1234].v

${R}/for-comp-by%.v: ${D}/bp-by-sta%.H ${D}/for-by%.H
	Merge $^ axis=3 space=n | Window min1=0.2 f2=5 | ${Wiggly} pclip=97 poly=y plotcol=${whi} plotfat=4 title="By observed (red) vs By modeled (blue)" out=${R}/tmpy1.v > ${dn}
	Merge $^ axis=3 space=n | Window min1=0.2 f2=5 | ${Wiggly} pclip=97 poly=n plotcol=${cya} plotfat=5 title="By observed (red) vs By modeled (blue)" out=${R}/tmpy2.v > ${dn}
	vppen < ${R}/tmpy1.v vpstyle=n out0=${R}/tmpy3.v out1=${dn} > ${dn}
	vppen < ${R}/tmpy2.v vpstyle=n out0=${dn}        out1=${R}/tmpy4.v  > ${dn}
	vp_Overlay ${R}/tmpy3.v ${R}/tmpy4.v > $@
	@rm ${R}/tmpy[1234].v

${R}/for-comp-bz%.v: ${D}/bp-bz-sta%.H ${D}/for-bz%.H
	Merge $^ axis=3 space=n | Window min1=0.2 f2=5 | ${Wiggly} pclip=97 poly=y plotcol=${whi} plotfat=4 title="Bz observed (red) vs Bz modeled (blue)" out=${R}/tmpz1.v > ${dn}
	Merge $^ axis=3 space=n | Window min1=0.2 f2=5 | ${Wiggly} pclip=97 poly=n plotcol=${cya} plotfat=5 title="Bz observed (red) vs Bz modeled (blue)" out=${R}/tmpz2.v > ${dn}
	vppen < ${R}/tmpz1.v vpstyle=n out0=${R}/tmpz3.v out1=${dn} > ${dn}
	vppen < ${R}/tmpz2.v vpstyle=n out0=${dn}        out1=${R}/tmpz4.v  > ${dn}
	vp_Overlay ${R}/tmpz3.v ${R}/tmpz4.v > $@
	@rm ${R}/tmpz[1234].v

# compare forward modeled magnetic projections with projection data using grey
${R}/for-gcomp%: \
	${D}/bp-bx-sta%.H ${D}/for-bx%.H \
	${D}/bp-by-sta%.H ${D}/for-by%.H \
	${D}/bp-bz-sta%.H ${D}/for-bz%.H

	Merge axis=3 space=n $^ | Scale rscale=1e+9 |\
	${Grey3} titles="Bx data:Bx modeled:By data:By modeled:Bz data:Bz modeled" barlabel="nanoTesla" out=${R}/tmpfor.v > ${dn}
	vppen < ${R}/tmpfor.v vpstyle=n \
	out0=$@-bx.v out1=$@-bxfor.v out2=$@-by.v out3=$@-byfor.v out4=$@-bz.v out5=$@-bzfor.v> ${dn}

# compare forward modeled magnetic projections from rotation sensor with forward modeled projections from magnetic rotations using wiggle
${R}/for-comp-brx%.v: ${D}/for-brx%.H ${D}/for-bx%.H
	Merge $^ axis=3 space=n | Window min1=0.2 f2=5 | ${Wiggly} pclip=97 poly=y plotcol=${whi} plotfat=4 title="Brx modeled (red) vs Bx modeled (blue)" out=${R}/tmpx1.v > ${dn}
	Merge $^ axis=3 space=n | Window min1=0.2 f2=5 | ${Wiggly} pclip=97 poly=n plotcol=${cya} plotfat=5 title="Brx modeled (red) vs Bx modeled (blue)" out=${R}/tmpx2.v > ${dn}
	vppen < ${R}/tmpx1.v vpstyle=n out0=${R}/tmpx3.v out1=${dn} > ${dn}
	vppen < ${R}/tmpx2.v vpstyle=n out0=${dn}        out1=${R}/tmpx4.v  > ${dn}
	vp_Overlay ${R}/tmpx3.v ${R}/tmpx4.v > $@
	@rm ${R}/tmpx[1234].v

${R}/for-comp-bry%.v: ${D}/for-bry%.H ${D}/for-by%.H
	Merge $^ axis=3 space=n | Window min1=0.2 f2=5 | ${Wiggly} pclip=97 poly=y plotcol=${whi} plotfat=4 title="Bry modeled (red) vs By modeled (blue)" out=${R}/tmpy1.v > ${dn}
	Merge $^ axis=3 space=n | Window min1=0.2 f2=5 | ${Wiggly} pclip=97 poly=n plotcol=${cya} plotfat=5 title="Bry modeled (red) vs By modeled (blue)" out=${R}/tmpy2.v > ${dn}
	vppen < ${R}/tmpy1.v vpstyle=n out0=${R}/tmpy3.v out1=${dn} > ${dn}
	vppen < ${R}/tmpy2.v vpstyle=n out0=${dn}        out1=${R}/tmpy4.v  > ${dn}
	vp_Overlay ${R}/tmpy3.v ${R}/tmpy4.v > $@
	@rm ${R}/tmpy[1234].v

${R}/for-comp-brz%.v: ${D}/for-brz%.H ${D}/for-bz%.H
	Merge $^ axis=3 space=n | Window min1=0.2 f2=5 | ${Wiggly} pclip=97 poly=y plotcol=${whi} plotfat=4 title="Brz modeled (red) vs Bz modeled (blue)" out=${R}/tmpz1.v > ${dn}
	Merge $^ axis=3 space=n | Window min1=0.2 f2=5 | ${Wiggly} pclip=97 poly=n plotcol=${cya} plotfat=5 title="Brz modeled (red) vs Bz modeled (blue)" out=${R}/tmpz2.v > ${dn}
	vppen < ${R}/tmpz1.v vpstyle=n out0=${R}/tmpz3.v out1=${dn} > ${dn}
	vppen < ${R}/tmpz2.v vpstyle=n out0=${dn}        out1=${R}/tmpz4.v  > ${dn}
	vp_Overlay ${R}/tmpz3.v ${R}/tmpz4.v > $@
	@rm ${R}/tmpz[1234].v

rot2mag:
	#Rm ${D}/for-b[xyz]-sta[123].H
	make ${D}/for-bx1.H ${D}/for-by1.H ${D}/for-bz1.H
	make ${D}/for-bx2.H ${D}/for-by2.H ${D}/for-bz2.H
	make ${D}/for-bx3.H ${D}/for-by3.H ${D}/for-bz3.H
	make ${R}/for-comp-bx1.v ${R}/for-comp-by1.v ${R}/for-comp-bz1.v
	make ${R}/for-comp-bx2.v ${R}/for-comp-by2.v ${R}/for-comp-bz2.v
	make ${R}/for-comp-bx3.v ${R}/for-comp-by3.v ${R}/for-comp-bz3.v
	make ${R}/for-comp-bx1.pdf ${R}/for-comp-by1.pdf ${R}/for-comp-bz1.pdf

	make ${D}/for-brx1.H ${D}/for-bry1.H ${D}/for-brz1.H
	make ${D}/for-brx2.H ${D}/for-bry2.H ${D}/for-brz2.H
	make ${D}/for-brx3.H ${D}/for-bry3.H ${D}/for-brz3.H
	make ${R}/for-comp-brx1.v ${R}/for-comp-bry1.v ${R}/for-comp-brz1.v
	make ${R}/for-comp-brx2.v ${R}/for-comp-bry2.v ${R}/for-comp-brz2.v
	make ${R}/for-comp-brx3.v ${R}/for-comp-bry3.v ${R}/for-comp-brz3.v
	make ${R}/for-comp-brx1.pdf ${R}/for-comp-bry1.pdf ${R}/for-comp-brz1.pdf

#======================
# phase shifts
#======================

# phase difference between observed magnetometer data and modeled projections from magnetic rotations
${D}/for-bx-sphd%.H: ${D}/bp-bx-sta%.H ${D}/for-bx%.H ${B}/phasematch-cc.x ${P}/desig-mag-phase.P
	Window < ${D}/bp-bx-sta$*.H f2=5 > ${D}/tmpbp$*.H
	Window < ${D}/for-bx$*.H    f2=5 > ${D}/tmpfor$*.H
	${B}/phasematch-cc.x file1=${D}/tmpfor$*.H file2=${D}/tmpbp$*.H par=${P}/desig-mag-phase.P \
	sphased=$@ > ${dn}
	@Rm ${D}/tmpbp$*.H ${D}/tmpfor$*.H

${D}/for-by-sphd%.H: ${D}/bp-by-sta%.H ${D}/for-by%.H ${B}/phasematch-cc.x ${P}/desig-mag-phase.P
	Window < ${D}/bp-by-sta$*.H f2=5 > ${D}/tmpbp$*.H
	Window < ${D}/for-by$*.H    f2=5 > ${D}/tmpfor$*.H
	${B}/phasematch-cc.x file1=${D}/tmpfor$*.H file2=${D}/tmpbp$*.H par=${P}/desig-mag-phase.P \
	sphased=$@ > ${dn}
	@Rm ${D}/tmpbp$*.H ${D}/tmpfor$*.H

${D}/for-bz-sphd%.H: ${D}/bp-bz-sta%.H ${D}/for-bz%.H ${B}/phasematch-cc.x ${P}/desig-mag-phase.P
	Window < ${D}/bp-bz-sta$*.H f2=5 > ${D}/tmpbp$*.H
	Window < ${D}/for-bz$*.H    f2=5 > ${D}/tmpfor$*.H
	${B}/phasematch-cc.x file1=${D}/tmpfor$*.H file2=${D}/tmpbp$*.H par=${P}/desig-mag-phase.P \
	sphased=$@ > ${dn}
	@Rm ${D}/tmpbp$*.H ${D}/tmpfor$*.H

# phase difference between observed magnetometer data and modeled projections from rotation sensors
${D}/for-brx-sphd%.H: ${D}/bp-bx-sta%.H ${D}/for-brx%.H ${B}/phasematch-cc.x ${P}/desig-mag-phase.P
	Window < ${D}/bp-bx-sta$*.H f2=5 > ${D}/tmpbp$*.H
	Window < ${D}/for-brx$*.H   f2=5 > ${D}/tmpfor$*.H
	${B}/phasematch-cc.x file1=${D}/tmpfor$*.H file2=${D}/tmpbp$*.H par=${P}/desig-mag-phase.P \
	sphased=$@ > ${dn}
	@Rm ${D}/tmpbp$*.H ${D}/tmpfor$*.H

${D}/for-bry-sphd%.H: ${D}/bp-by-sta%.H ${D}/for-bry%.H ${B}/phasematch-cc.x ${P}/desig-mag-phase.P
	Window < ${D}/bp-by-sta$*.H f2=5 > ${D}/tmpbp$*.H
	Window < ${D}/for-bry$*.H   f2=5 > ${D}/tmpfor$*.H
	${B}/phasematch-cc.x file1=${D}/tmpfor$*.H file2=${D}/tmpbp$*.H par=${P}/desig-mag-phase.P \
	sphased=$@ > ${dn}
	@Rm ${D}/tmpbp$*.H ${D}/tmpfor$*.H

${D}/for-brz-sphd%.H: ${D}/bp-bz-sta%.H ${D}/for-brz%.H ${B}/phasematch-cc.x ${P}/desig-mag-phase.P
	Window < ${D}/bp-bz-sta$*.H f2=5 > ${D}/tmpbp$*.H
	Window < ${D}/for-brz$*.H   f2=5 > ${D}/tmpfor$*.H
	${B}/phasematch-cc.x file1=${D}/tmpfor$*.H file2=${D}/tmpbp$*.H par=${P}/desig-mag-phase.P \
	sphased=$@ > ${dn}
	@Rm ${D}/tmpbp$*.H ${D}/tmpfor$*.H

# phase shift of Bx
${R}/for-bx-phasediffs.v: ${D}/for-bx-sphd1.H ${D}/for-bx-sphd2.H ${D}/for-bx-sphd3.H
	Merge $^ axis=2 space=n | Window min1=3 max1=30 |\
	${GraphPS} title="modeled Bx phase lags" legendloc=tl out=$@ > ${dn}

${R}/for-brx-phasediffs.v: ${D}/for-brx-sphd1.H ${D}/for-brx-sphd2.H ${D}/for-brx-sphd3.H
	Merge $^ axis=2 space=n | Window min1=3 max1=30 |\
	${GraphPS} title="modeled Bx phase lags" legendloc=tl out=$@ > ${dn}

# phase shift of By
${R}/for-by-phasediffs.v: ${D}/for-by-sphd1.H ${D}/for-by-sphd2.H ${D}/for-by-sphd3.H
	Merge $^ axis=2 space=n | Window min1=3 max1=30 |\
	${GraphPS} title="modeled By phase lags" legendloc=tl out=$@ > ${dn}

${R}/for-bry-phasediffs.v: ${D}/for-bry-sphd1.H ${D}/for-bry-sphd2.H ${D}/for-bry-sphd3.H
	Merge $^ axis=2 space=n | Window min1=3 max1=30 |\
	${GraphPS} title="modeled By phase lags" legendloc=tl out=$@ > ${dn}

# phase shift of Bz
${R}/for-bz-phasediffs.v: ${D}/for-bz-sphd1.H ${D}/for-bz-sphd2.H ${D}/for-bz-sphd3.H
	Merge $^ axis=2 space=n | Window min1=3 max1=30 |\
	${GraphPS} title="modeled Bz phase lags" legendloc=tl out=$@ > ${dn}

${R}/for-brz-phasediffs.v: ${D}/for-brz-sphd1.H ${D}/for-brz-sphd2.H ${D}/for-brz-sphd3.H
	Merge $^ axis=2 space=n | Window min1=3 max1=30 |\
	${GraphPS} title="modeled Bz phase lags" legendloc=tl out=$@ > ${dn}

rot2magps:
	make ${D}/for-bx-sphd1.H ${D}/for-by-sphd1.H ${D}/for-bz-sphd1.H
	make ${D}/for-bx-sphd2.H ${D}/for-by-sphd2.H ${D}/for-bz-sphd2.H
	make ${D}/for-bx-sphd3.H ${D}/for-by-sphd3.H ${D}/for-bz-sphd3.H
	make ${R}/for-bx-phasediffs.v ${R}/for-by-phasediffs.v ${R}/for-bz-phasediffs.v
	make ${R}/for-bx-phasediffs.pdf ${R}/for-by-phasediffs.pdf ${R}/for-bz-phasediffs.pdf
	make ${D}/for-brx-sphd1.H ${D}/for-bry-sphd1.H ${D}/for-brz-sphd1.H
	make ${D}/for-brx-sphd2.H ${D}/for-bry-sphd2.H ${D}/for-brz-sphd2.H
	make ${D}/for-brx-sphd3.H ${D}/for-bry-sphd3.H ${D}/for-brz-sphd3.H
	make ${R}/for-brx-phasediffs.v ${R}/for-bry-phasediffs.v ${R}/for-brz-phasediffs.v
	make ${R}/for-brx-phasediffs.pdf ${R}/for-bry-phasediffs.pdf ${R}/for-brz-phasediffs.pdf

#===============================
# apply adjoint (magnetic projections to rotations) 
# on forward modeled rotations
#===============================

${D}/for-bx-val%.H ${D}/for-by-val%.H ${D}/for-bz-val%.H: ${D}/for-bx%.H ${D}/for-by%.H ${D}/for-bz%.H
	Scale < ${D}/for-bx$*.H rscale=1e+9 | Math file1=in exp='file1+${Xintensity}' > ${D}/for-bx-val$*.H
	Scale < ${D}/for-by$*.H rscale=1e+9 | Math file1=in exp='file1+${Yintensity}' > ${D}/for-by-val$*.H
	Scale < ${D}/for-bz$*.H rscale=1e+9 | Math file1=in exp='file1+${Zintensity}' > ${D}/for-bz-val$*.H

${D}/adj-rx%.H ${D}/adj-ry%.H ${D}/adj-rz%.H: ${B}/Rtheta_vector.x ${B}/firstderiv.x \
	${D}/for-bx-val%.H ${D}/for-by-val%.H ${D}/for-bz-val%.H

	${B}/Rtheta_vector.x X=${D}/for-bx-val$*.H Y=${D}/for-by-val$*.H Z=${D}/for-bz-val$*.H \
	euler=${D}/adj-euler$*.H \
	jt=10 eps=1e-30 > ${dn}

	Window3d < ${D}/adj-euler$*.H n2=1 f2=0 | ${BP1} > ${D}/adj-Rx$*.H
	Window3d < ${D}/adj-euler$*.H n2=1 f2=1 | ${BP1} > ${D}/adj-Ry$*.H
	Window3d < ${D}/adj-euler$*.H n2=1 f2=2 | ${BP1} > ${D}/adj-Rz$*.H
	
	${B}/firstderiv.x < ${D}/adj-Rx$*.H | ${BP1} > ${D}/adj-rx$*.H
	${B}/firstderiv.x < ${D}/adj-Ry$*.H | ${BP1} > ${D}/adj-ry$*.H
	${B}/firstderiv.x < ${D}/adj-Rz$*.H | ${BP1} > ${D}/adj-rz$*.H

# compare adjoint rotations with rotation data using wiggle
${R}/adj-comp-rx%.v: ${D}/rx-sta%-lshift.H ${D}/adj-rx%.H
	Merge $^ axis=3 space=n | Window min1=0.2 f2=5 | ${Wiggly} pclip=97 poly=y plotcol=${whi} plotfat=4 title="Roll data (red) vs Roll adjoint (blue)" out=${R}/tmpx1.v > ${dn}
	Merge $^ axis=3 space=n | Window min1=0.2 f2=5 | ${Wiggly} pclip=97 poly=n plotcol=${cya} plotfat=5 title="Roll data (red) vs Roll adjoint (blue)" out=${R}/tmpx2.v > ${dn}
	vppen < ${R}/tmpx1.v vpstyle=n out0=${R}/tmpx3.v out1=${dn} > ${dn}
	vppen < ${R}/tmpx2.v vpstyle=n out0=${dn}        out1=${R}/tmpx4.v  > ${dn}
	vp_Overlay ${R}/tmpx3.v ${R}/tmpx4.v > $@
	@rm ${R}/tmpx[1234].v

${R}/adj-comp-ry%.v: ${D}/ry-sta%-lshift.H ${D}/adj-ry%.H
	Merge $^ axis=3 space=n | Window min1=0.2 f2=5 | ${Wiggly} pclip=97 poly=y plotcol=${whi} plotfat=4 title="Pitch data (red) vs Pitch adjoint (blue)" out=${R}/tmpy1.v > ${dn}
	Merge $^ axis=3 space=n | Window min1=0.2 f2=5 | ${Wiggly} pclip=97 poly=n plotcol=${cya} plotfat=5 title="Pitch data (red) vs Pitch adjoint (blue)" out=${R}/tmpy2.v > ${dn}
	vppen < ${R}/tmpy1.v vpstyle=n out0=${R}/tmpy3.v out1=${dn} > ${dn}
	vppen < ${R}/tmpy2.v vpstyle=n out0=${dn}        out1=${R}/tmpy4.v  > ${dn}
	vp_Overlay ${R}/tmpy3.v ${R}/tmpy4.v > $@
	@rm ${R}/tmpy[1234].v

${R}/adj-comp-rz%.v: ${D}/rz-sta%-lshift.H ${D}/adj-rz%.H
	Merge $^ axis=3 space=n | Window min1=0.2 f2=5 | ${Wiggly} pclip=97 poly=y plotcol=${whi} plotfat=4 title="Yaw data (red) vs Yaw adjoint (blue)" out=${R}/tmpz1.v > ${dn}
	Merge $^ axis=3 space=n | Window min1=0.2 f2=5 | ${Wiggly} pclip=97 poly=n plotcol=${cya} plotfat=5 title="Yaw data (red) vs Yaw adjoint (blue)" out=${R}/tmpz2.v > ${dn}
	vppen < ${R}/tmpz1.v vpstyle=n out0=${R}/tmpz3.v out1=${dn} > ${dn}
	vppen < ${R}/tmpz2.v vpstyle=n out0=${dn}        out1=${R}/tmpz4.v  > ${dn}
	vp_Overlay ${R}/tmpz3.v ${R}/tmpz4.v > $@
	@rm ${R}/tmpz[1234].v

# compare adjoint rotations with rotation data using grey
${R}/adj-gcomp%: \
	${D}/rx-sta%-lshift.H ${D}/adj-rx%.H \
	${D}/ry-sta%-lshift.H ${D}/adj-ry%.H \
	${D}/rz-sta%-lshift.H ${D}/adj-rz%.H

	Merge axis=3 space=n $^ | Scale rscale=1e+3 |\
	${Grey3} titles="Roll data:Roll adjoint:Pitch data:Pitch adjoint:Yaw data:Yaw adjoint" out=${R}/tmpadj.v > ${dn}
	vppen < ${R}/tmpadj.v vpstyle=n \
	out0=$@-rx.v out1=$@-rxadj.v out2=$@-ry.v out3=$@-ryadj.v out4=$@-rz.v out5=$@-rzadj.v> ${dn}

mag2rotadj:
	make ${D}/adj-rx1.H ${D}/adj-ry1.H ${D}/adj-rz1.H
	make ${D}/adj-rx2.H ${D}/adj-ry2.H ${D}/adj-rz2.H
	make ${D}/adj-rx3.H ${D}/adj-ry3.H ${D}/adj-rz3.H

	make ${R}/adj-comp-rx1.v ${R}/adj-comp-ry1.v ${R}/adj-comp-rz1.v
	make ${R}/adj-comp-rx2.v ${R}/adj-comp-ry2.v ${R}/adj-comp-rz2.v
	make ${R}/adj-comp-rx3.v ${R}/adj-comp-ry3.v ${R}/adj-comp-rz3.v
	make ${R}/adj-gcomp1 ${R}/adj-gcomp2 ${R}/adj-gcomp3

	make ${R}/adj-comp-rx1.pdf ${R}/adj-comp-ry1.pdf ${R}/adj-comp-rz1.pdf
	make ${R}/adj-gcomp1-rx.pdf ${R}/adj-gcomp1-rxadj.pdf
	make ${R}/adj-gcomp1-ry.pdf ${R}/adj-gcomp1-ryadj.pdf
	make ${R}/adj-gcomp1-rz.pdf ${R}/adj-gcomp1-rzadj.pdf

#======================
# phase shifts
#======================

# phase difference between rotation data and adjoint rotations
${D}/adj-rx-sphd%.H: ${D}/rx-sta%-lshift.H ${D}/adj-rx%.H ${B}/phasematch-cc.x ${P}/desig-mag-phase.P
	Window < ${D}/rx-sta$*-lshift.H f2=5 > ${D}/tmprx$*.H
	Window < ${D}/adj-rx$*.H f2=5 > ${D}/tmpadjrx$*.H
	${B}/phasematch-cc.x file1=${D}/tmpadjrx$*.H file2=${D}/tmprx$*.H par=${P}/desig-mag-phase.P \
	sphased=$@ > ${dn}
	@Rm ${D}/tmprx$*.H ${D}/tmpadjrx$*.H

${D}/adj-ry-sphd%.H: ${D}/ry-sta%-lshift.H ${D}/adj-ry%.H ${B}/phasematch-cc.x ${P}/desig-mag-phase.P
	Window < ${D}/ry-sta$*-lshift.H f2=5 > ${D}/tmpry$*.H
	Window < ${D}/adj-ry$*.H f2=5 > ${D}/tmpadjry$*.H
	${B}/phasematch-cc.x file1=${D}/tmpadjry$*.H file2=${D}/tmpry$*.H par=${P}/desig-mag-phase.P \
	sphased=$@ > ${dn}
	@Rm ${D}/tmpry$*.H ${D}/tmpadjry$*.H

${D}/adj-rz-sphd%.H: ${D}/rz-sta%-lshift.H ${D}/adj-rz%.H ${B}/phasematch-cc.x ${P}/desig-mag-phase.P
	Window < ${D}/rz-sta$*-lshift.H f2=5 > ${D}/tmprz$*.H
	Window < ${D}/adj-rz$*.H f2=5 > ${D}/tmpadjrz$*.H
	${B}/phasematch-cc.x file1=${D}/tmpadjrz$*.H file2=${D}/tmprz$*.H par=${P}/desig-mag-phase.P \
	sphased=$@ > ${dn}
	@Rm ${D}/tmprz$*.H ${D}/tmpadjrz$*.H

# phase shift of adjoint rx
${R}/adj-rx-phasediffs.v: ${D}/adj-rx-sphd1.H ${D}/adj-rx-sphd2.H ${D}/adj-rx-sphd3.H
	Merge $^ axis=2 space=n | Window min1=3 max1=30 |\
	${GraphPS} title="adjoint roll phase lags" out=$@ > ${dn}

# phase shift of adjoint ry
${R}/adj-ry-phasediffs.v: ${D}/adj-ry-sphd1.H ${D}/adj-ry-sphd2.H ${D}/adj-ry-sphd3.H
	Merge $^ axis=2 space=n | Window min1=3 max1=30 |\
	${GraphPS} title="adjoint pitch phase lags" out=$@ > ${dn}

# phase shift of adjoint rz
${R}/adj-rz-phasediffs.v: ${D}/adj-rz-sphd1.H ${D}/adj-rz-sphd2.H ${D}/adj-rz-sphd3.H
	Merge $^ axis=2 space=n | Window min1=3 max1=30 |\
	${GraphPS} title="adjoint yaw phase lags" out=$@ > ${dn}

mag2rotadjps:
	make ${D}/adj-rx-sphd1.H ${D}/adj-ry-sphd1.H ${D}/adj-rz-sphd1.H
	make ${D}/adj-rx-sphd2.H ${D}/adj-ry-sphd2.H ${D}/adj-rz-sphd2.H
	make ${D}/adj-rx-sphd3.H ${D}/adj-ry-sphd3.H ${D}/adj-rz-sphd3.H
	make ${R}/adj-rx-phasediffs.v ${R}/adj-ry-phasediffs.v ${R}/adj-rz-phasediffs.v
	make ${R}/adj-rx-phasediffs.pdf ${R}/adj-ry-phasediffs.pdf ${R}/adj-rz-phasediffs.pdf

