# Resample rotation sensors to dt=0.001, to match with seismic.
# the data have already been bandpassed, so we should not need to do this, but we'll bandpass it anyway to be sure.
# bandpass all other data identically

BP1      = Bandpass flo=3 fhi=30 phase=0
BP4DESIG = Bandpass flo=3 fhi=30 phase=0
WIN1     = Window min1=0 max1=0.8
Interp2seismic = Interp d1out=0.001
SENS_ROT = 0.02

# vertical geophone
${D}/active-vz-bp.H: ${D}/active-vz-vol.H
	${BP1} < $< | ${WIN1} > $@

############################################################
# rotations from rotation sensors, bandpassed up to 50 Hz
############################################################
${D}/rotations-bp.H: ${D}/rotations.H
	Math file1=$< exp='file1*${SENS_ROT}' | ${BP1} | ${Interp2seismic} | Pad end1=1 > $@

${D}/rx-bp.H: ${D}/rotations-bp.H
	Window < $< f3=0 j3=3 n3=3 > $@

${D}/ry-bp.H: ${D}/rotations-bp.H
	Window < $< f3=1 j3=3 n3=3 > $@

${D}/rz-bp.H: ${D}/rotations-bp.H
	Window < $< f3=2 j3=3 n3=3 > $@


# pitch and roll separated by station number
${D}/r%-sta1.H: ${D}/r%-bp.H
	Window < $< n3=1 f3=0 | ${WIN1} > $@

${D}/r%-sta2.H: ${D}/r%-bp.H
	Window < $< n3=1 f3=1 | ${WIN1} > $@

${D}/r%-sta3.H: ${D}/r%-bp.H
	Window < $< n3=1 f3=2 | ${WIN1} > $@

${D}/vz-r%-sta1.H: ${D}/active-vz-r%-vol.H
	Window < $< n3=1 f3=0 | ${WIN1} > $@

${D}/vz-r%-sta2.H: ${D}/active-vz-r%-vol.H
	Window < $< n3=1 f3=1 | ${WIN1} > $@

${D}/vz-r%-sta3.H: ${D}/active-vz-r%-vol.H
	Window < $< n3=1 f3=2 | ${WIN1} > $@

############################################################
# rotations from rotation sensors, bandpassed up to 30 Hz for designature (spatial aliasing of adjacent vertical geophones above 30 Hz)
############################################################
${D}/rotations-bp4desig.H: ${D}/rotations.H
	Math file1=$< exp='file1*${SENS_ROT}' | ${BP4DESIG} | Interp d1out=0.001 | Pad end1=1 > $@

${D}/rx-bp4desig.H: ${D}/rotations-bp4desig.H
	Window < $< f3=0 j3=3 n3=3 > $@

${D}/ry-bp4desig.H: ${D}/rotations-bp4desig.H
	Window < $< f3=1 j3=3 n3=3 > $@

${D}/rz-bp4desig.H: ${D}/rotations-bp4desig.H
	Window < $< f3=2 j3=3 n3=3 > $@


# pitch and roll separated by station number
${D}/r%-bpsta1.H: ${D}/r%-bp4desig.H
	Window < $< n3=1 f3=0 | ${WIN1} > $@

${D}/r%-bpsta2.H: ${D}/r%-bp4desig.H
	Window < $< n3=1 f3=1 | ${WIN1} > $@

${D}/r%-bpsta3.H: ${D}/r%-bp4desig.H
	Window < $< n3=1 f3=2 | ${WIN1} > $@

${D}/vz-r%-bpsta1.H: ${D}/active-vz-r%-bp4desig-vol.H
	Window < $< n3=1 f3=0 | ${WIN1} > $@

${D}/vz-r%-bpsta2.H: ${D}/active-vz-r%-bp4desig-vol.H
	Window < $< n3=1 f3=1 | ${WIN1} > $@

${D}/vz-r%-bpsta3.H: ${D}/active-vz-r%-bp4desig-vol.H
	Window < $< n3=1 f3=2 | ${WIN1} > $@

stations:
	#Rm ${D}/rotations-bp.H
	#Rm ${D}/r[xyz]-bp.H ${D}/r[zxy]-sta[123].H ${D}/vz-r[xy]-sta[123].H
	make ${D}/rx-sta1.H ${D}/rx-sta2.H ${D}/rx-sta3.H
	make ${D}/ry-sta1.H ${D}/ry-sta2.H ${D}/ry-sta3.H
	make ${D}/rz-sta1.H ${D}/rz-sta2.H ${D}/rz-sta3.H
	make ${D}/vz-rx-sta1.H ${D}/vz-rx-sta2.H ${D}/vz-rx-sta3.H
	make ${D}/vz-ry-sta1.H ${D}/vz-ry-sta2.H ${D}/vz-ry-sta3.H
	#Rm ${D}/r[xy]-bpsta[123].H ${D}/vz-r[xy]-bpsta[123].H
	make ${D}/rx-bpsta1.H ${D}/rx-bpsta2.H ${D}/rx-bpsta3.H
	make ${D}/ry-bpsta1.H ${D}/ry-bpsta2.H ${D}/ry-bpsta3.H
	make ${D}/vz-rx-bpsta1.H ${D}/vz-rx-bpsta2.H ${D}/vz-rx-bpsta3.H
	make ${D}/vz-ry-bpsta1.H ${D}/vz-ry-bpsta2.H ${D}/vz-ry-bpsta3.H

############################################
# find the phase difference between the rotations from -d(Vz)/dx and rotations from Ry sensor
# and output it to the file ${D}/ry-lphd(station#).H
############################################

${D}/ry-lphd%.H ${D}/ry-sphd%.H: ${D}/ry-bpsta%.H ${D}/vz-ry-bpsta%.H ${B}/phasematch-cc.x ${P}/desig-rot-phase.P
	${B}/phasematch-cc.x file1=${D}/ry-bpsta$*.H file2=${D}/vz-ry-bpsta$*.H par=${P}/desig-rot-phase.P \
	amp=${D}/ry-amp$*.H phased=${D}/ry-phd$*.H sphased=${D}/ry-sphd$*.H lphased=${D}/ry-lphd$*.H corr=${D}/ry-corr$*.H > ${dn}

############################################
# find the phase difference between the rotations from d(Vz)/dy and rotations from Rx sensor
# and output it to the file ${D}/rx-lphd(station#).H
############################################

${D}/rx-lphd%.H ${D}/rx-sphd%.H: ${D}/rx-bpsta%.H ${D}/vz-rx-bpsta%.H ${B}/phasematch-cc.x ${P}/desig-rot-phase.P
	${B}/phasematch-cc.x file1=${D}/rx-bpsta$*.H file2=${D}/vz-rx-bpsta$*.H par=${P}/desig-rot-phase.P \
	amp=${D}/rx-amp$*.H phased=${D}/rx-phd$*.H sphased=${D}/rx-sphd$*.H lphased=${D}/rx-lphd$*.H corr=${D}/rx-corr$*.H > ${dn}

############################################
# phase shift Rz, Rx and Ry using phase difference calculated from difference of Ry vs. d(Vz)/dx
# and from difference of Rx vs. d(Vz)/dy
############################################

${D}/ry-sta%-lshift.H: ${D}/ry-sta%.H ${D}/ry-lphd%.H ${B}/phaseshift.x
	${B}/phaseshift.x < $< phase=${D}/ry-lphd$*.H > $@

# for Rx, use the phase shift calculated for the pitch sensor at station 1, since the other rolls are unstable
${D}/rx-sta%-lshift.H: ${D}/rx-sta%.H ${D}/ry-lphd1.H ${B}/phaseshift.x
	${B}/phaseshift.x < $< phase=${D}/ry-lphd1.H > $@

# for Rz, use the phase shift calculated for the pitch sensor at station 1
${D}/rz-sta%-lshift.H: ${D}/rz-sta%.H ${D}/ry-lphd1.H ${B}/phaseshift.x
	${B}/phaseshift.x < $< phase=${D}/ry-lphd1.H > $@

#======================
# phase shift figures
#======================
# phase shift of pitch
${R}/ry-phasediffs.v: ${D}/ry-sphd1.H ${D}/ry-sphd2.H ${D}/ry-sphd3.H ${D}/ry-lphd1.H ${D}/ry-lphd2.H ${D}/ry-lphd3.H
	Merge ${D}/ry-sphd1.H ${D}/ry-sphd2.H ${D}/ry-sphd3.H axis=2 space=n | Window min1=3 max1=30 |\
	${GraphPS} title="Pitch phase lags" out=$@ > ${dn}

# phase shift of roll: extremely unstable
${R}/rx-phasediffs.v: ${D}/rx-sphd1.H ${D}/rx-sphd2.H ${D}/rx-sphd3.H ${D}/rx-lphd1.H ${D}/rx-lphd2.H ${D}/rx-lphd3.H
	Merge ${D}/rx-sphd1.H ${D}/rx-sphd2.H ${D}/rx-sphd3.H axis=2 space=n | Window min1=3 max1=30 |\
	${GraphPS} title="Roll phase lags" out=$@ > ${dn}

# before-after phase shift data figures
${R}/comp-ry-sta%: ${D}/ry-sta%.H ${D}/vz-ry-sta%.H ${D}/ry-sta%-lshift.H
	Balance < ${D}/vz-ry-sta$*.H | ${Wiggly} plotcol=${cya} title="Pitch: geophone-diff (blue) vs rotation sensor (red)" titlesz=8 out=${R}/tmp1.v > ${dn}
	Balance < ${D}/ry-sta$*.H | ${Wiggly} plotcol=${yel} poly=n out=${R}/tmp2.v > ${dn}
	Balance < ${D}/ry-sta$*-lshift.H | ${Wiggly} plotcol=${yel} poly=n out=${R}/tmp3.v > ${dn}
	vp_Overlay ${R}/tmp1.v ${R}/tmp2.v > $@-before.v
	vp_Overlay ${R}/tmp1.v ${R}/tmp3.v > $@-after.v
	rm ${R}/tmp[12].v

${R}/comp-rx-sta%: ${D}/rx-sta%.H ${D}/vz-rx-sta%.H  ${D}/rx-sta%-lshift.H
	Balance < ${D}/vz-rx-sta$*.H | ${Wiggly} plotcol=${cya} title="Roll: geophone-diff (blue) vs rotation sensor (red)" titlesz=8 out=${R}/tmp1.v > ${dn}
	Balance < ${D}/rx-sta$*.H | ${Wiggly} plotcol=${yel} poly=n out=${R}/tmp2.v > ${dn}
	Balance < ${D}/rx-sta$*-lshift.H | ${Wiggly} plotcol=${yel} poly=n out=${R}/tmp3.v > ${dn}
	vp_Overlay ${R}/tmp1.v ${R}/tmp2.v > $@-before.v
	vp_Overlay ${R}/tmp1.v ${R}/tmp3.v > $@-after.v
	rm ${R}/tmp[12].v

${R}/comp-rz-sta%: ${D}/rz-sta%.H ${D}/rz-sta%-lshift.H
	Balance < ${D}/rz-sta$*.H | ${Wiggly} plotcol=${yel} title="Yaw: rotation sensor" poly=n out=$@-before.v > ${dn}
	Balance < ${D}/rz-sta$*-lshift.H | ${Wiggly} plotcol=${yel} title="Yaw: rotation sensor" poly=n out=$@-after.v > ${dn}

# correlation lags of vertical geophone difference and rotation sensors, before and after phase matching
${R}/clags-ry-sta%: ${D}/ry-sta%.H ${D}/vz-ry-sta%.H ${D}/ry-sta%-lshift.H ${B}/lagtrace.x
	${B}/lagtrace.x file1=${D}/ry-sta$*.H        file2=${D}/vz-ry-sta$*.H corr=${D}/$(@F)-before.H > ${dn}
	${B}/lagtrace.x file1=${D}/ry-sta$*-lshift.H file2=${D}/vz-ry-sta$*.H corr=${D}/$(@F)-after.H  > ${dn}
	Balance < ${D}/$(@F)-before.H | Window3d min1=-0.08 max1=0.08 | ${Wiggly} label1="pitch correlation lag (sec)" title="station $*" out=$@-before.v > ${dn}
	Balance < ${D}/$(@F)-after.H  | Window3d min1=-0.08 max1=0.08 | ${Wiggly} label1="pitch correlation lag (sec)" title="station $*" out=$@-after.v > ${dn}

${R}/clags-rx-sta%: ${D}/rx-sta%.H ${D}/vz-rx-sta%.H ${D}/rx-sta%-lshift.H ${B}/lagtrace.x
	${B}/lagtrace.x file1=${D}/rx-sta$*.H        file2=${D}/vz-rx-sta$*.H corr=${D}/$(@F)-before.H > ${dn}
	${B}/lagtrace.x file1=${D}/rx-sta$*-lshift.H file2=${D}/vz-rx-sta$*.H corr=${D}/$(@F)-after.H  > ${dn}
	Balance < ${D}/$(@F)-before.H | Window3d min1=-0.08 max1=0.08 | ${Wiggly} label1="roll correlation lag (sec)" title="station $*" out=$@-before.v > ${dn}
	Balance < ${D}/$(@F)-after.H  | Window3d min1=-0.08 max1=0.08 | ${Wiggly} label1="roll correlation lag (sec)" title="station $*" out=$@-after.v > ${dn}


phaseshift:
	make ${R}/ry-phasediffs.v ${R}/rx-phasediffs.v
	make ${R}/comp-ry-sta1 ${R}/comp-ry-sta2 ${R}/comp-ry-sta3
	make ${R}/comp-rx-sta1 ${R}/comp-rx-sta2 ${R}/comp-rx-sta3
	make ${R}/comp-rz-sta1 ${R}/comp-rz-sta2 ${R}/comp-rz-sta3

	make ${R}/ry-phasediffs.pdf ${R}/rx-phasediffs.pdf
	make ${R}/comp-ry-sta1-before.pdf ${R}/comp-rx-sta1-before.pdf ${R}/comp-rz-sta1-before.pdf
	make ${R}/comp-ry-sta1-after.pdf ${R}/comp-rx-sta1-after.pdf ${R}/comp-rz-sta1-after.pdf

