#################################################################################
# Receiver layout and channel numbering.
# The geophones were connected to the geode in the order of channels specified here.
#--------------------------
#
# Az=30 (+Y)
# ^
# |
# |
# |
# |						G22(0.00,1.18)							G21(1.75,1.15)							G17(3.45,1.13)
# |
# |	G24(-0.90,0.00)		R(0.00,0.00)		G20(0.90,0.00)		R(1.75,0.00)		G18(2.60,0.00)		R(3.45,0.00)		G15(4.30,0.00)								G14(7.3,0.00) .... (13 more channels at 3m intervals till G1)
# |
# |						G23(0,00,-1.18)							G19(1.75,-1.15)							G16(3.45,-1.13)
# |
# |
# |
# |
# --------------------------------------------------> Az=120 (+X)
#################################################################################

###################################
# designature the geophones
# I think these are 40 Hz geophones, the ones used by Valentina Fontiveros in her Master's thesis from 2010,
# and the ones used by Seth Haines in his Ph.D. thesis from 2004.
###################################
# descaling factor for the default preamb gain=24dB on the Geode recording system. This converts from the input data samples into millivolts
DESCALE24 = 0.00016985

# descaling factor for a preamb gain=36dB on the Geode recording system
DESCALE36 = 0.000042704

# According to the IRIS/PASSCAL website, the L-40 geophones used by Valentina Fontiveros in Surprise valley have a sensitivity of 21 V/m/s, and are critically damped at 0.555.
# We use SENS=21000 because after the descaling, the data is in millivolts.
#DAMP = 55.5
#SENS = 21000

# We now (May 12th 2015) think that the geophones we used are not 40 Hz. Possibly they are 10 Hz.
# The geophones 'SM' written on them, and I think they are produced by Ion Geophysical.
# according to spec sheets on iongeo.com, for a 10 Hz SM-24 geophone element, the sensitivity is 28.8 V/m/s, and the damping is 0.6
# We use SENS=28800 because after the descaling, the data is in millivolts.
#DAMP = 60
#SENS = 28800

${D}/active-vz-descale.H: ${D}/active-vz.H
	Scale rscale=${DESCALE24} < $< > $@

${D}/active-vz-desig.H: ${D}/active-vz-descale.H ${B}/gpdesig.x ${P}/vzdesig.f10.P
	${B}/gpdesig.x < $< par=${P}/vzdesig.f10.P sensy=${D}/f10-geophone-response.H > $@

${D}/active-vz-f10-desig.H: ${D}/active-vz-descale.H ${B}/gpdesig.x ${P}/vzdesig.f10.P
	${B}/gpdesig.x < $< par=${P}/vzdesig.f10.P sensy=${D}/f10-geophone-response.H > $@

${D}/active-vz-f40-desig.H: ${D}/active-vz-descale.H ${B}/gpdesig.x ${P}/vzdesig.f40.P
	${B}/gpdesig.x < $< par=${P}/vzdesig.f40.P sensy=${D}/f40-geophone-response.H > $@

${D}/passive-vz-descale.H: ${D}/passive-vz.H
	Scale rscale=${DESCALE24} < $< > $@

${D}/passive-vz-desig.H: ${D}/passive-vz-descale.H ${B}/gpdesig.x ${P}/vzdesig.f10.P
	${B}/gpdesig.x < $< par=${P}/vzdesig.f10.P > $@

${D}/passive-vz-f40-desig.H: ${D}/passive-vz-descale.H ${B}/gpdesig.x ${P}/vzdesig.f40.P
	${B}/gpdesig.x < $< par=${P}/vzdesig.f40.P > $@

