#################################################################################
# Receiver layout and channel numbering.
# The geophones were connected to the geode in the order of channels specified here.
#--------------------------
#
# Az=30 (+Y)
# ^
# |
# |
# |
# |						G22(0.00,1.18)							G21(1.75,1.15)							G17(3.45,1.13)
# |
# |	G24(-0.90,0.00)		R(0.00,0.00)		G20(0.90,0.00)		R(1.75,0.00)		G18(2.60,0.00)		R(3.45,0.00)		G15(4.30,0.00)								G14(7.3,0.00) .... (13 more channels at 3m intervals till G1)
# |
# |						G23(0,00,-1.18)							G19(1.75,-1.15)							G16(3.45,-1.13)
# |
# |
# |
# |
# --------------------------------------------------> Az=120 (+X)
#################################################################################

#######################################
# Generate rotations from geophone differencing.
# +X component is East(ish), +Y component is North(ish).
# To retain consistency with the rotation sensor pitch components (ry=-dx(vz)) we difference the nodes: -(east-west)/dx = (west-east)/dx.
# To retain consistency with the rotation sensor roll components  (rx=dy(vz)) we difference the nodes:  (north-south)/dy.
#######################################
${D}/vz-chan%.H: ${D}/active-vz-f40-desig.H
	Window_key < $< key1=tracf mink1=$* maxk1=$* synch=1 > ${D}/tmpvz.H hff=$@@@
	echo "hff=-1" >> ${D}/tmpvz.H
	${BP1} < ${D}/tmpvz.H > $@
	echo "hff=$@@@" >> $@
	@Rm ${D}/tmpvz.H

${D}/vz-bp-chan%.H: ${D}/active-vz-f40-desig.H
	Window_key < $< key1=tracf mink1=$* maxk1=$* synch=1 > ${D}/tmpvz.H hff=$@@@
	echo "hff=-1" >> ${D}/tmpvz.H
	${BP4DESIG} < ${D}/tmpvz.H > $@
	echo "hff=$@@@" >> $@
	@Rm ${D}/tmpvz.H

${D}/vz-sta1.H: ${D}/vz-chan22.H
	Infill3d < $< | ${WIN1} > $@
	echo "o2=-5" >> $@
	echo "d2=-5" >> $@

${D}/vz-sta2.H: ${D}/vz-chan21.H
	Infill3d < $< | ${WIN1} > $@
	echo "o2=-5" >> $@
	echo "d2=-5" >> $@

${D}/vz-sta3.H: ${D}/vz-chan17.H
	Infill3d < $< | ${WIN1} > $@
	echo "o2=-5" >> $@
	echo "d2=-5" >> $@


${D}/vz-ry.H: ${D}/vz-chan24.H ${D}/vz-chan20.H ${D}/vz-chan18.H ${D}/vz-chan15.H
	# (east-west)/dx
	#Add scale=0.55555555,-0.55555555 ${D}/vz-chan20.H ${D}/vz-chan24.H > ${D}/vz-ry1.H hff=${D}/vz-ry1.H@@
	#Add scale=0.58823529,-0.58823529 ${D}/vz-chan18.H ${D}/vz-chan20.H > ${D}/vz-ry2.H hff=${D}/vz-ry2.H@@
	#Add scale=0.58823529,-0.58823529 ${D}/vz-chan15.H ${D}/vz-chan18.H > ${D}/vz-ry3.H hff=${D}/vz-ry3.H@@
	# (west-east)/dx
	Add scale=-0.55555555,0.55555555 ${D}/vz-chan20.H ${D}/vz-chan24.H > ${D}/vz-ry1.H hff=${D}/vz-ry1.H@@
	Add scale=-0.58823529,0.58823529 ${D}/vz-chan18.H ${D}/vz-chan20.H > ${D}/vz-ry2.H hff=${D}/vz-ry2.H@@
	Add scale=-0.58823529,0.58823529 ${D}/vz-chan15.H ${D}/vz-chan18.H > ${D}/vz-ry3.H hff=${D}/vz-ry3.H@@
	Cat3d ${D}/vz-ry1.H ${D}/vz-ry2.H ${D}/vz-ry3.H > $@ hff=$@@@
	rm ${D}/vz-ry[123].H

${D}/vz-rx.H: ${D}/vz-chan22.H ${D}/vz-chan23.H ${D}/vz-chan21.H ${D}/vz-chan19.H ${D}/vz-chan17.H ${D}/vz-chan16.H
	# (south-north)/dy
	#Add scale=0.42372881,-0.42372881 ${D}/vz-chan23.H ${D}/vz-chan22.H > ${D}/vz-rx1.H hff=${D}/vz-rx1.H@@
	#Add scale=0.43478260,-0.43478260 ${D}/vz-chan21.H ${D}/vz-chan19.H > ${D}/vz-rx2.H hff=${D}/vz-rx2.H@@
	#Add scale=0.44247787,-0.44247787 ${D}/vz-chan17.H ${D}/vz-chan16.H > ${D}/vz-rx3.H hff=${D}/vz-rx3.H@@
	# (north-south)/dy
	Add scale=-0.42372881,0.42372881 ${D}/vz-chan23.H ${D}/vz-chan22.H > ${D}/vz-rx1.H hff=${D}/vz-rx1.H@@
	Add scale=-0.43478260,0.43478260 ${D}/vz-chan21.H ${D}/vz-chan19.H > ${D}/vz-rx2.H hff=${D}/vz-rx2.H@@
	Add scale=-0.44247787,0.44247787 ${D}/vz-chan17.H ${D}/vz-chan16.H > ${D}/vz-rx3.H hff=${D}/vz-rx3.H@@
	Cat3d ${D}/vz-rx1.H ${D}/vz-rx2.H ${D}/vz-rx3.H > $@ hff=$@@@
	rm ${D}/vz-rx[123].H

${D}/vz-ry-bp4desig.H: ${D}/vz-bp-chan24.H ${D}/vz-bp-chan20.H ${D}/vz-bp-chan18.H ${D}/vz-bp-chan15.H
	# (east-west)/dx
	#Add scale=0.55555555,-0.55555555 ${D}/vz-bp-chan20.H ${D}/vz-bp-chan24.H > ${D}/vz-bp-ry1.H hff=${D}/vz-bp-ry1.H@@
	#Add scale=0.58823529,-0.58823529 ${D}/vz-bp-chan18.H ${D}/vz-bp-chan20.H > ${D}/vz-bp-ry2.H hff=${D}/vz-bp-ry2.H@@
	#Add scale=0.58823529,-0.58823529 ${D}/vz-bp-chan15.H ${D}/vz-bp-chan18.H > ${D}/vz-bp-ry3.H hff=${D}/vz-bp-ry3.H@@
	# (west-east)/dx
	Add scale=-0.55555555,0.55555555 ${D}/vz-bp-chan20.H ${D}/vz-bp-chan24.H > ${D}/vz-bp-ry1.H hff=${D}/vz-bp-ry1.H@@
	Add scale=-0.58823529,0.58823529 ${D}/vz-bp-chan18.H ${D}/vz-bp-chan20.H > ${D}/vz-bp-ry2.H hff=${D}/vz-bp-ry2.H@@
	Add scale=-0.58823529,0.58823529 ${D}/vz-bp-chan15.H ${D}/vz-bp-chan18.H > ${D}/vz-bp-ry3.H hff=${D}/vz-bp-ry3.H@@
	Cat3d ${D}/vz-bp-ry1.H ${D}/vz-bp-ry2.H ${D}/vz-bp-ry3.H > $@ hff=$@@@
	rm ${D}/vz-bp-ry[123].H

${D}/vz-rx-bp4desig.H: ${D}/vz-bp-chan22.H ${D}/vz-bp-chan23.H ${D}/vz-bp-chan21.H ${D}/vz-bp-chan19.H ${D}/vz-bp-chan17.H ${D}/vz-bp-chan16.H
	# (south-north)/dy
	#Add scale=0.42372881,-0.42372881 ${D}/vz-bp-chan23.H ${D}/vz-bp-chan22.H > ${D}/vz-bp-rx1.H hff=${D}/vz-bp-rx1.H@@
	#Add scale=0.43478260,-0.43478260 ${D}/vz-bp-chan21.H ${D}/vz-bp-chan19.H > ${D}/vz-bp-rx2.H hff=${D}/vz-bp-rx2.H@@
	#Add scale=0.44247787,-0.44247787 ${D}/vz-bp-chan17.H ${D}/vz-bp-chan16.H > ${D}/vz-bp-rx3.H hff=${D}/vz-bp-rx3.H@@
	# (north-south)/dy
	Add scale=-0.42372881,0.42372881 ${D}/vz-bp-chan23.H ${D}/vz-bp-chan22.H > ${D}/vz-bp-rx1.H hff=${D}/vz-bp-rx1.H@@
	Add scale=-0.43478260,0.43478260 ${D}/vz-bp-chan21.H ${D}/vz-bp-chan19.H > ${D}/vz-bp-rx2.H hff=${D}/vz-bp-rx2.H@@
	Add scale=-0.44247787,0.44247787 ${D}/vz-bp-chan17.H ${D}/vz-bp-chan16.H > ${D}/vz-bp-rx3.H hff=${D}/vz-bp-rx3.H@@
	Cat3d ${D}/vz-bp-rx1.H ${D}/vz-bp-rx2.H ${D}/vz-bp-rx3.H > $@ hff=$@@@
	rm ${D}/vz-bp-rx[123].H

vzrot: 
	rm -f ${D}/vz*-chan*.H*
	rm -f ${D}/vz-r[xy]-bp4desig.H
	rm -f ${D}/vz-r[xy].H
	make ${D}/vz-ry.H ${D}/vz-rx.H
	make ${D}/vz-ry-bp4desig.H ${D}/vz-rx-bp4desig.H

############################
# generate receiver gather volumes
############################
${D}/active-vz-channelsort.H: ${D}/active-vz-f40-desig.H
	Sort3d < $< nkeys=2 \
	key1=Sx		ng1=${ns}		og1=${os}	dg1=${ds} \
	key2=tracf	ng2=${nchan}	og2=24		dg2=-1	\
	> $@ hff=$@@@ gff=$@@@@@ # sorted by channel# (slow axis) / shot position (fast axis)

${D}/active-vz-vol.H: ${D}/active-vz-channelsort.H
	Infill3d < $< > $@

${D}/active-vz-ry-channelsort.H: ${D}/vz-ry.H
	Sort3d < $< nkeys=2 \
	key1=Sx		ng1=${ns}	og1=${os}	dg1=${ds} \
	key2=Gx		ng2=3		og2=5.		dg2=-2.	\
	> $@ hff=$@@@ gff=$@@@@@ # sorted by Gx (slow axis) / shot position (fast axis)

${D}/active-vz-rx-channelsort.H: ${D}/vz-rx.H
	Sort3d < $< nkeys=2 \
	key1=Sx		ng1=${ns}	og1=${os}	dg1=${ds} \
	key2=Gx		ng2=3		og2=4.1		dg2=-2.	\
	> $@ hff=$@@@ gff=$@@@@@ # sorted by Gx (slow axis) / shot position (fast axis)

${D}/active-vz-r%-vol.H: ${D}/active-vz-r%-channelsort.H
	Infill3d < $< | Reverse which=4 > $@

${D}/active-vz-ry-bp4desig-channelsort.H: ${D}/vz-ry-bp4desig.H
	Sort3d < $< nkeys=2 \
	key1=Sx		ng1=${ns}	og1=${os}	dg1=${ds} \
	key2=Gx		ng2=3		og2=5.		dg2=-2.	\
	> $@ hff=$@@@ gff=$@@@@@ # sorted by Gx (slow axis) / shot position (fast axis)

${D}/active-vz-rx-bp4desig-channelsort.H: ${D}/vz-rx-bp4desig.H
	Sort3d < $< nkeys=2 \
	key1=Sx		ng1=${ns}	og1=${os}	dg1=${ds} \
	key2=Gx		ng2=3		og2=4.1		dg2=-2.	\
	> $@ hff=$@@@ gff=$@@@@@ # sorted by Gx (slow axis) / shot position (fast axis)

${D}/active-vz-r%-bp4desig-vol.H: ${D}/active-vz-r%-bp4desig-channelsort.H
	Infill3d < $< | Reverse which=4 > $@

${D}/vz-and-rxy.H: ${D}/active-vz-vol.H ${D}/active-vz-ry-vol.H ${D}/active-vz-rx-vol.H
	Window3d < ${D}/active-vz-vol.H n3=1 f3=0 | ${BP1} > ${D}/vz-1.H
	Window3d < ${D}/active-vz-vol.H n3=1 f3=4 | ${BP1} > ${D}/vz-2.H
	Window3d < ${D}/active-vz-vol.H n3=1 f3=6 | ${BP1} > ${D}/vz-3.H
	Window3d < ${D}/active-vz-ry-vol.H n3=1 f3=2 | ${BP1} > ${D}/vz-ry-1.H
	Window3d < ${D}/active-vz-ry-vol.H n3=1 f3=1 | ${BP1} > ${D}/vz-ry-2.H
	Window3d < ${D}/active-vz-ry-vol.H n3=1 f3=0 | ${BP1} > ${D}/vz-ry-3.H
	Window3d < ${D}/active-vz-rx-vol.H n3=1 f3=2 | ${BP1} > ${D}/vz-rx-1.H
	Window3d < ${D}/active-vz-rx-vol.H n3=1 f3=1 | ${BP1} > ${D}/vz-rx-2.H
	Window3d < ${D}/active-vz-rx-vol.H n3=1 f3=0 | ${BP1} > ${D}/vz-rx-3.H
	Merge \
	${D}/vz-1.H ${D}/vz-ry-1.H ${D}/vz-rx-1.H \
	${D}/vz-2.H ${D}/vz-ry-2.H ${D}/vz-rx-2.H \
	${D}/vz-3.H ${D}/vz-ry-3.H ${D}/vz-rx-3.H  axis=3 space=n > $@
	rm ${D}/vz-[123].H ${D}/vz-ry-[123].H ${D}/vz-rx-[123].H

