! get rotations in terms of the the unit vector around which the rotation takes place, and the amount of rotation
! 
!
! n1 = time axis
! n2 = trace number
!

program Rtheta_vector
	use sep
	use quat_mod
	implicit none


	integer, external :: sreed, srite
	integer	:: n1, n2, it, i2, jt
	real	:: d1, o1, d2, o2, d3, o3
	real	:: eps=0.
	real(kind=8)	:: eps_dp, idt, denom, cos_theta_dp, test_acos
	real, parameter	:: deg2rad = 4.*atan(1.)/180.
	type(quat_dp) :: q1
	type(quat) :: q_sp

	real, allocatable, dimension (:,:)	:: X_in,  Y_in, Z_in	! input data of the X,Y,Z components
	real, allocatable, dimension (:,:)	:: theta				! first time derivative of the angle of rotation between the magnetic vector's projection
																! on the magnetic components over two consecutive time steps
	real, allocatable, dimension (:,:,:)	:: uvec				! unit vector (rotation axis) around which the rotation took place over two consecutive time samples.
	real, allocatable, dimension (:,:,:)	:: euler_rot		! rotations in terms of euler angles in the Tait-Bryan convention

	real(kind=8), allocatable, dimension (:,:)	:: X_dp,  Y_dp, Z_dp
	real(kind=8), allocatable, dimension (:,:)	:: theta_dp
	real(kind=8), allocatable, dimension (:,:,:)	:: uvec_dp

	call sep_init()

	call from_aux ("X", "n1", n1)
	call from_aux ("X", "o1", o1)
	call from_aux ("X", "d1", d1)
	call from_aux ("X", "n2", n2, 1)
	call from_aux ("X", "o2", o2, 0.)
	call from_aux ("X", "d2", d2, 1.)


	idt = DBLE(1./d1)

	call from_param ('jt', jt, 100)
	call from_param ('eps', eps, 1e-20)
	eps_dp = DBLE(eps)

	if (exist_file ("theta")) then
		call to_history ("n1", n1, "theta")
		call to_history ("o1", o1, "theta")
		call to_history ("d1", d1, "theta")
		call to_history ("n2", n2, "theta")
		call to_history ("o2", o2, "theta")
		call to_history ("d2", d2, "theta")

	endif
	if (exist_file ("uvec")) then
		call to_history ("n1", n1, "uvec")
		call to_history ("o1", o1, "uvec")
		call to_history ("d1", d1, "uvec")
		call to_history ("n2", 3,  "uvec")
		call to_history ("o2", 0., "uvec")
		call to_history ("d2", 1., "uvec")
		call to_history ("n3", n2, "uvec")
		call to_history ("o3", o2, "uvec")
		call to_history ("d3", d2, "uvec")
	endif
	if (exist_file ("euler")) then
		call to_history ("n1", n1, "euler")
		call to_history ("o1", o1, "euler")
		call to_history ("d1", d1, "euler")
		call to_history ("n2", 3,  "euler")
		call to_history ("o2", 0., "euler")
		call to_history ("d2", 1., "euler")
		call to_history ("n3", n2, "euler")
		call to_history ("o3", o2, "euler")
		call to_history ("d3", d2, "euler")
	endif
	if (exist_file ("qout")) then
		call to_history ("n1", 4,  "qout")
		call to_history ("o1", 0., "qout")
		call to_history ("d1", 1., "qout")
		call to_history ("n2", n1, "qout")
		call to_history ("o2", o1, "qout")
		call to_history ("d2", d1, "qout")
		call to_history ("n3", n2, "qout")
		call to_history ("o3", o2, "qout")
		call to_history ("d3", d2, "qout")
	endif

	allocate (X_in(n1,n2), Y_in(n1,n2), Z_in(n1,n2))
	allocate (X_dp(n1,n2), Y_dp(n1,n2), Z_dp(n1,n2))
	allocate (theta(n1,n2),    uvec(n1,3,n2), euler_rot(n1,3,n2))
	allocate (theta_dp(n1,n2), uvec_dp(n1,3,n2))

	theta = 0.; uvec = 0.; theta_dp = 0.; uvec_dp = 0.; euler_rot = 0.

	if (sreed ("X", X_in, 4*n1*n2) .ne. 4*n1*n2) call seperr ("error reading from input file X")
	if (sreed ("Y", Y_in, 4*n1*n2) .ne. 4*n1*n2) call seperr ("error reading from input file Y")
	if (sreed ("Z", Z_in, 4*n1*n2) .ne. 4*n1*n2) call seperr ("error reading from input file Z")


	X_dp = X_in
	Y_dp = Y_in
	Z_dp = Z_in

	q1 = qnew (DBLE(1.), DBLE(0.), DBLE(0.), DBLE(0.))
	q_sp = qnew (1.,0.,0.,0.)
	if (exist_file ("qout")) then
		call q_sp%quat_write ("qout")
	endif

	! calculate rotation for all time samples other than the first one
	do i2 = 1, n2
	do it = 2, n1
		!write (0,*), " "
		!write (0,*), " "
		!write (0,*), "i2, it:", i2, it
		!write (0,*), "X, Y, Z at it-1 =", X_dp(it-1,i2), Y_dp(it-1,i2), Z_dp(it-1,i2)
		!write (0,*), "X, Y, Z at it   =", X_dp(it,i2), Y_dp(it,i2), Z_dp(it,i2)

		! calculate the rotation angle: theta_dp=acos(a dot a' / |a|*|a'|)
		! where <a'> is the current magentic vector projection and <a> is the previous time step's projection.
		cos_theta_dp = (X_dp(it,i2)*X_dp(it-1,i2) + Y_dp(it,i2)*Y_dp(it-1,i2) + Z_dp(it,i2)*Z_dp(it-1,i2)) / &
		( sqrt(X_dp(it,  i2)*X_dp(it,  i2) + Y_dp(it,  i2)*Y_dp(it,  i2) + Z_dp(it,  i2)*Z_dp(it,  i2)) &
		* sqrt(X_dp(it-1,i2)*X_dp(it-1,i2) + Y_dp(it-1,i2)*Y_dp(it-1,i2) + Z_dp(it-1,i2)*Z_dp(it-1,i2)))

		test_acos = acos (cos_theta_dp)

		if (isnan (test_acos)) then
			theta_dp=DBLE(0.)
		else
			theta_dp (it, i2) = test_acos
		endif

		!write (0,*), "theta = ", theta_dp(it,i2)

		! calculate the rotation axis unit vector: u=(a x a' / |a x a'|)
		! where <a'> is the current magentic vector projection and <a> is the previous time step's projection.
		uvec_dp (it,1,i2) = Y_dp(it-1,i2)*Z_dp(it,i2) - Z_dp(it-1,i2)*Y_dp(it,i2)
		uvec_dp (it,2,i2) = Z_dp(it-1,i2)*X_dp(it,i2) - X_dp(it-1,i2)*Z_dp(it,i2)
		uvec_dp (it,3,i2) = X_dp(it-1,i2)*Y_dp(it,i2) - Y_dp(it-1,i2)*X_dp(it,i2)

		!write (0,*), "unr", uvec_dp(it,1,i2), uvec_dp(it,2,i2), uvec_dp(it,3,i2)

		denom = 1. / (sqrt(uvec_dp(it,1,i2)*uvec_dp(it,1,i2) + uvec_dp(it,2,i2)*uvec_dp(it,2,i2) + uvec_dp(it,3,i2)*uvec_dp(it,3,i2)) + eps_dp)
		uvec_dp (it,1,i2) = uvec_dp(it,1,i2) * denom
		uvec_dp (it,2,i2) = uvec_dp(it,2,i2) * denom
		uvec_dp (it,3,i2) = uvec_dp(it,3,i2) * denom

		!write (0,*), "denom = ", denom
		!write (0,*), "nrm", uvec_dp(it,1,i2), uvec_dp(it,2,i2), uvec_dp(it,3,i2)

		! rotate the quaternion using the axis and angle
		call q1%quat_dp_mult_fromangle (theta_dp(it,i2), uvec_dp(it,1,i2), uvec_dp(it,2,i2), uvec_dp(it,3,i2))

		!call q1%quat_dp_print ()

		if (mod(it,jt) == 0) then
			call q1%quat_dp_norm ()
		endif

		if (exist_file ("qout")) then
			call q1%quat_dp2sp (q_sp)
			call q_sp%quat_write ("qout")
		endif

		! convert to an euler angle representation of the quaternion
		call q1%quat_dp2euler (euler_rot(it,1,i2), euler_rot(it,2,i2), euler_rot(it,3,i2))
	end do
	call q_sp%quat_write ("qout")
	end do


	theta = REAL(theta_dp)
	uvec  = REAL(uvec_dp)

	if (exist_file ("theta")) then
		if (srite ("theta", theta, 4*n1*n2) .ne. 4*n1*n2) call seperr ("error writing to output file theta")
	endif
	if (exist_file ("uvec")) then
		if (srite ("uvec", uvec, 4*n1*3*n2) .ne. 4*n1*3*n2) call seperr ("error writing to output file uvec")
	endif

	if (exist_file ("euler")) then
		if (srite ("euler", euler_rot, 4*n1*3*n2) .ne. 4*n1*3*n2) call seperr ("error writing to output file euler")
	endif
	deallocate (X_in, Y_in, Z_in, theta, uvec, euler_rot, X_dp, Y_dp, z_dp, theta_dp, uvec_dp)

	call sep_close()

end program Rtheta_vector
