module divstack_mod
	implicit none

	real, allocatable, dimension (:)	:: scales

contains
	! diversity stack subroutine - removes bursty noise. Just a weighted average really.
	! from sudivstack help:
	! Diversity stacking is a noise reduction technique used in the      
	! summation of duplicate data. Each trace is scaled by the inverse   
	! of its average power prior to stacking.  The composite trace is    
	! then renormalized by dividing by the sum of the scalers used.      

	subroutine divstack (ain, aout, winsize)
		real, dimension (:,:), intent(in)	:: ain
		real, dimension (:), intent (out)	:: aout
		integer, intent (in)				:: winsize ! window length
		integer								:: nwin ! number of windows
		integer								:: tail ! tail length
		integer								:: i1, i2, iw
		logical								:: nans
		real								:: tmpsum, x

		aout = 0.

		if (.not. allocated (scales)) allocate (scales (size (ain,2)))

		nwin = INT (size (ain,1) / winsize)

		do iw = 0, nwin-1
			nans=.false.
			do i2 = 1, size (scales)
				tmpsum = sum (ain (iw*winsize+1:(iw+1)*winsize+1, i2)**2)
				if (tmpsum .gt. 0.) scales (i2) = winsize / tmpsum
				if (isnan (scales (i2)) .or. scales(i2) >= HUGE(x)) nans=.true.
			end do
			if (.not. nans) then
				do i1 = 1, winsize
					tmpsum = sum (scales)
					if (tmpsum .gt. 0.) aout (iw*winsize+i1) = sum (ain (iw*winsize+i1, :) * scales(:)) / tmpsum
				end do
			endif
		end do

		tail = size (ain,1) - nwin*winsize

		nans=.false.
		do i2 = 1, size (scales)
			tmpsum = sum (ain (size (ain,1)-tail+1 : size (ain,1), i2)**2)
			if ( tmpsum .gt. 0.) scales = tail / tmpsum
			if (isnan (scales (i2)) .or. scales(i2) >= HUGE(x)) nans=.true.
		end do
		if (.not. nans) then
			do i1 = 1, tail
				tmpsum = sum (scales)
				if (tmpsum .gt. 0.) aout (size (ain,1)-tail+i1) = sum (ain (size (ain,1)-tail+i1, :) * scales(:)) / tmpsum
			end do
		endif

	end subroutine

end module divstack_mod
