! match the phase of one section with that of another
module env_mod
	use base_fftwfl_mod
	use base_fftwv3_mod
	implicit none
contains

subroutine envelope (data)

	real, parameter						:: pi=4.*atan(1.)
	real, dimension (:,:), intent(inout)	:: data			! input data
	complex, allocatable, dimension (:)	:: data_t		! complex input data
	complex, allocatable, dimension (:)	:: data_f		! data after Fourier transform
	integer								:: n1, n2	! data dimensions
	integer								:: fn1		! dimensions in fourier space
	integer								:: i1, i2	! counters
	integer*8							:: plan1, plan2, plan3		! for fourier transform

	n1  = size (data, 1)
	fn1 = n1

	allocate (data_t  (fn1))
	allocate (data_f  (fn1))

	call sfftw_plan_dft_1d (plan1, fn1, data_t, data_f, FFTW_FORWARD, FFTW_ESTIMATE)
	call sfftw_plan_dft_1d (plan2, fn1, data_f, data_t, FFTW_BACKWARD, FFTW_ESTIMATE)

	do i2 = 1, size (data, 2)
		data_t = cmplx (0., 0.)
		data_f = cmplx (0., 0.)
		data_t (:) = data (:, i2)
	
		! do forward tranform
		call sfftw_execute (plan1)
	
		! Zero negative frequencies, and multiply positive frequencies by 2, except for DC and nyquist
		! DC is at 1, nyquist is at fn1/2+1.
		! f(t) ---[FT]---> f(w)
		! Fh(t)---[FT]---> i*sign(w)*f(w)
		! V(w) = f(w) - i*Fh(w) = (1+sign(w))*f(w)
		data_f (2:fn1/2)     = 2. * data_f (2:fn1/2)
		data_f (fn1/2+2:fn1) = cmplx (0., 0.)

		! in SEPlib's Envelope program, we do this instead:
		!data_f (fn1/2+2:fn1) = cmplx (0., 0.)
		!data_f (fn1/2+1) = 0.5 * data_f (fn1/2+1)
		!data_f (1) = 0.5 * data_f (1)

		! do inverse tranform
		call sfftw_execute(plan2)

		! use absolute value as envelope
		data (1:n1, i2) = cabs (data_t) / fn1

	end do

	call sfftw_destroy_plan(plan1)
	call sfftw_destroy_plan(plan2)
	deallocate (data_t, data_f)
end subroutine

end module
