! Input 3C rotations in euler angles and the magnetic projection on each axis.
! Rotate the projection vector according to the input rotations.
! output the rotated projections,
! 
! n1 = time axis
! n2, n3 = trace number
!

program euler_rot
	use sep
	implicit none


	integer, external :: sreed, srite, sep_get_data_axis_par
	integer	:: n1, n2, n3
	integer	:: i1, i2, i3
	real	:: d1, o1, d2, o2, d3, o3
	real	:: eps, abx, aby, abz
	real(kind=8)	:: eps_dp, abx_dp, aby_dp, abz_dp
	real, parameter	:: deg2rad = 4.*atan(1.)/180.

	real, allocatable, dimension (:,:,:)		:: sp
	real(kind=8), allocatable, dimension (:,:,:)	:: rx_dp, ry_dp, rz_dp
	real(kind=8), allocatable, dimension (:,:,:)	:: bx_dp, by_dp, bz_dp


	call sep_init()

	!if (0 .ne. sep_get_data_axis_par ("rx", 1, n1, o1, d1)) &
	!	call seperr ("error obtaining dimensions of Rx input file")
	!if (0 .ne. sep_get_data_axis_par ("rx", 2, n2, o2, d2)) &
	!	call seperr ("error obtaining dimensions of Rx input file")
	!if (0 .ne. sep_get_data_axis_par ("rx", 3, n3, o3, d3)) &
	!	call seperr ("error obtaining dimensions of Rx input file")

	call from_aux ("rx", "n1", n1)
	call from_aux ("rx", "o1", o1)
	call from_aux ("rx", "d1", d1)
	call from_aux ("rx", "n2", n2)
	call from_aux ("rx", "o2", o2)
	call from_aux ("rx", "d2", d2)
	call from_aux ("rx", "n3", n3)
	call from_aux ("rx", "o3", o3)
	call from_aux ("rx", "d3", d3)

	call to_history ("n1", n1, "bx")
	call to_history ("o1", o1, "bx")
	call to_history ("d1", d1, "bx")
	call to_history ("n2", n2, "bx")
	call to_history ("o2", o2, "bx")
	call to_history ("d2", d2, "bx")
	call to_history ("n3", n3, "bx")
	call to_history ("o3", o3, "bx")
	call to_history ("d3", d3, "bx")
	call to_history ("n1", n1, "by")
	call to_history ("o1", o1, "by")
	call to_history ("d1", d1, "by")
	call to_history ("n2", n2, "by")
	call to_history ("o2", o2, "by")
	call to_history ("d2", d2, "by")
	call to_history ("n3", n3, "by")
	call to_history ("o3", o3, "by")
	call to_history ("d3", d3, "by")
	call to_history ("n1", n1, "bz")
	call to_history ("o1", o1, "bz")
	call to_history ("d1", d1, "bz")
	call to_history ("n2", n2, "bz")
	call to_history ("o2", o2, "bz")
	call to_history ("d2", d2, "bz")
	call to_history ("n3", n3, "bz")
	call to_history ("o3", o3, "bz")
	call to_history ("d3", d3, "bz")

!	call sep_put_data_axis_par ("bx", 1, n1, o1, d1)
!	call sep_put_data_axis_par ("bx", 2, n2, o2, d2)
!	call sep_put_data_axis_par ("bx", 3, n3, o3, d3)
!	call sep_put_data_axis_par ("by", 1, n1, o1, d1)
!	call sep_put_data_axis_par ("by", 2, n2, o2, d2)
!	call sep_put_data_axis_par ("by", 3, n3, o3, d3)
!	call sep_put_data_axis_par ("bz", 1, n1, o1, d1)
!	call sep_put_data_axis_par ("bz", 2, n2, o2, d2)
!	call sep_put_data_axis_par ("bz", 3, n3, o3, d3)

	call from_param ('abx', abx, 1.)
	call from_param ('aby', aby, 1.)
	call from_param ('abz', abz, 1.)
	call from_param ('eps', eps, 1e-20)
	eps_dp = DBLE(eps)
	abx_dp = DBLE(abx)
	aby_dp = DBLE(aby)
	abz_dp = DBLE(abz)


	allocate (sp (n1, n2, n3))
	allocate (rx_dp (n1, n2, n3))
	allocate (ry_dp (n1, n2, n3))
	allocate (rz_dp (n1, n2, n3))
	allocate (bx_dp (n1, n2, n3))
	allocate (by_dp (n1, n2, n3))
	allocate (bz_dp (n1, n2, n3))

	bx_dp = DBLE (0.)
	by_dp = DBLE (0.)
	bz_dp = DBLE (0.)

	write (0,*), "abx =", abx_dp
	write (0,*), "aby =", aby_dp
	write (0,*), "abz =", abz_dp

	if (sreed ("rx", sp, n1*n2*n3*4) .ne. n1*n2*n3*4) call seperr ("error reading from rx input file")
	rx_dp = sp
	if (sreed ("ry", sp, n1*n2*n3*4) .ne. n1*n2*n3*4) call seperr ("error reading from ry input file")
	ry_dp = sp
	if (sreed ("rz", sp, n1*n2*n3*4) .ne. n1*n2*n3*4) call seperr ("error reading from rz input file")
	rz_dp = sp

	! 3D rotation with Tait-Bryan angles in order X1,Y2,Z3 (wikipedia has a list of various rotation matrices in various orders)
	! here we are assuming that the induced current in the induction coil magnetometer depends only on the original orientation
	! of the magnetometers in relation to the ambient magnetic field.
	bx_dp = abx_dp * cos (ry_dp) * cos (rz_dp) &
		  - aby_dp * cos (ry_dp) * sin (rz_dp) &
		  + abz_dp * sin (ry_dp)

	by_dp = abx_dp * (cos (rx_dp) * sin (rz_dp) + cos (rz_dp) * sin (rx_dp) * sin (ry_dp)) &
		  + aby_dp * (cos (rx_dp) * cos (rz_dp) - sin (rx_dp) * sin (ry_dp) * sin (rz_dp)) &
		  - abz_dp * (cos (ry_dp) * sin (rx_dp))

	bz_dp = abx_dp * (sin (rx_dp) * sin (rz_dp) - cos (rx_dp) * cos (rz_dp) * sin (ry_dp)) &
		  + aby_dp * (cos (rz_dp) * sin (rx_dp) + cos (rx_dp) * sin (ry_dp) * sin (rz_dp)) &
		  + abz_dp * (cos (rx_dp) * cos (ry_dp))

!	! 3D rotation with Tait-Bryan angles in order X1,Y2,Z3 (wikipedia has a list of various rotation matrices in various orders)
!	! here we are assuming that the induced current in the induction coil magnetometer depends on the previous orientation of the magnetometers
!	! in relation to the ambient magnetic field at the previous timestep
!	do i3=1,n3
!	do i2=1,n2
!
!		bx_dp (1,i2,i3) = abx_dp * cos (ry_dp (1,i2,i3)) * cos (rz_dp (1,i2,i3)) &
!						- aby_dp * cos (ry_dp (1,i2,i3)) * sin (rz_dp (1,i2,i3)) &
!						+ abz_dp * sin (ry_dp (1,i2,i3))
!
!		by_dp (1,i2,i3) = abx_dp * (cos (rx_dp (1,i2,i3)) * sin (rz_dp (1,i2,i3)) + cos (rz_dp (1,i2,i3)) * sin (rx_dp (1,i2,i3)) * sin (ry_dp (1,i2,i3))) &
!						+ aby_dp * (cos (rx_dp (1,i2,i3)) * cos (rz_dp (1,i2,i3)) - sin (rx_dp (1,i2,i3)) * sin (ry_dp (1,i2,i3)) * sin (rz_dp (1,i2,i3))) &
!						- abz_dp * (cos (ry_dp (1,i2,i3)) * sin (rx_dp (1,i2,i3)))
!
!		bz_dp (1,i2,i3) = abx_dp * (sin (rx_dp (1,i2,i3)) * sin (rz_dp (1,i2,i3)) - cos (rx_dp (1,i2,i3)) * cos (rz_dp (1,i2,i3)) * sin (ry_dp (1,i2,i3))) &
!						+ aby_dp * (cos (rz_dp (1,i2,i3)) * sin (rx_dp (1,i2,i3)) + cos (rx_dp (1,i2,i3)) * sin (ry_dp (1,i2,i3)) * sin (rz_dp (1,i2,i3))) &
!						+ abz_dp * (cos (rx_dp (1,i2,i3)) * cos (ry_dp (1,i2,i3)))
!		do i1=2,n1
!
!			bx_dp (i1,i2,i3) = bx_dp (i1-1,i2,i3) * cos (ry_dp (i1,i2,i3)) * cos (rz_dp (i1,i2,i3)) &
!							 - by_dp (i1-1,i2,i3) * cos (ry_dp (i1,i2,i3)) * sin (rz_dp (i1,i2,i3)) &
!							 + bz_dp (i1-1,i2,i3) * sin (ry_dp (i1,i2,i3))
!
!			by_dp (i1,i2,i3) = bx_dp (i1-1,i2,i3) * (cos (rx_dp (i1,i2,i3)) * sin (rz_dp (i1,i2,i3)) + cos (rz_dp (i1,i2,i3)) * sin (rx_dp (i1,i2,i3)) * sin (ry_dp (i1,i2,i3))) &
!							 + by_dp (i1-1,i2,i3) * (cos (rx_dp (i1,i2,i3)) * cos (rz_dp (i1,i2,i3)) - sin (rx_dp (i1,i2,i3)) * sin (ry_dp (i1,i2,i3)) * sin (rz_dp (i1,i2,i3))) &
!							 - bz_dp (i1-1,i2,i3) * (cos (ry_dp (i1,i2,i3)) * sin (rx_dp (i1,i2,i3)))
!
!			bz_dp (i1,i2,i3) = bx_dp (i1-1,i2,i3) * (sin (rx_dp (i1,i2,i3)) * sin (rz_dp (i1,i2,i3)) - cos (rx_dp (i1,i2,i3)) * cos (rz_dp (i1,i2,i3)) * sin (ry_dp (i1,i2,i3))) &
!							 + by_dp (i1-1,i2,i3) * (cos (rz_dp (i1,i2,i3)) * sin (rx_dp (i1,i2,i3)) + cos (rx_dp (i1,i2,i3)) * sin (ry_dp (i1,i2,i3)) * sin (rz_dp (i1,i2,i3))) &
!							 + bz_dp (i1-1,i2,i3) * (cos (rx_dp (i1,i2,i3)) * cos (ry_dp (i1,i2,i3)))
!
!		end do
!	end do
!	end do

	sp = bx_dp - abx_dp
	if (srite ("bx", sp, n1*n2*n3*4) .ne. n1*n2*n3*4) call seperr ("error writing to bx output file")
	sp = by_dp - aby_dp
	if (srite ("by", sp, n1*n2*n3*4) .ne. n1*n2*n3*4) call seperr ("error writing to by output file")
	sp = bz_dp - abz_dp
	if (srite ("bz", sp, n1*n2*n3*4) .ne. n1*n2*n3*4) call seperr ("error writing to bz output file")

	call sep_close()

	deallocate (sp, rx_dp, ry_dp, rz_dp, bx_dp, by_dp, bz_dp)
end program euler_rot
