module fftshift_mod

	implicit none

contains
	! Arrange spectrum so that the 'dim' axis is centered on zero, nyquist is on the negative edge.
	! The nyquist is at n/2+1.
	subroutine fftshift2d (arr, dim)
		complex, dimension (:,:), intent (inout)	:: arr
		integer, intent(in)							:: dim
		integer										:: n1, n2, i1, i2
		complex, allocatable, dimension(:,:)		:: temp

		n1 = size (arr, 1)
		n2 = size (arr, 2)
		allocate (temp (n1, n2))

		if (dim .eq. 2) then
			do i2=n2/2+1, n2
			do i1=1, n1
				temp (i1, i2 - n2/2) = arr (i1, i2)
			end do
			end do

			do i2=1, n2/2
			do i1=1, n1
				temp (i1, i2 + n2/2) = arr (i1, i2)
			end do
			end do
		endif

		if (dim .eq. 1) then
			do i2=1, n2
			do i1=n1/2+1, n1
				temp (i1 - n1/2, i2) = arr (i1, i2)
			end do
			do i1=1, n1/2
				temp (i1 + n1/2, i2) = arr (i1, i2)
			end do
			end do
		endif
		arr = temp
		deallocate (temp)
	end subroutine
	subroutine rfftshift2d (arr, dim)
		real, dimension (:,:), intent (inout)	:: arr
		integer, intent(in)						:: dim
		integer									:: n1, n2, i1, i2
		real, allocatable, dimension(:,:)		:: temp

		n1 = size (arr, 1)
		n2 = size (arr, 2)
		allocate (temp (n1, n2))

		if (dim .eq. 2) then
			do i2=n2/2+1, n2
			do i1=1, n1
				temp (i1, i2 - n2/2) = arr (i1, i2)
			end do
			end do

			do i2=1, n2/2
			do i1=1, n1
				temp (i1, i2 + n2/2) = arr (i1, i2)
			end do
			end do
		endif

		if (dim .eq. 1) then
			do i2=1, n2
			do i1=n1/2+1, n1
				temp (i1 - n1/2, i2) = arr (i1, i2)
			end do
			do i1=1, n1/2
				temp (i1 + n1/2, i2) = arr (i1, i2)
			end do
			end do
		endif
		arr = temp
		deallocate (temp)
	end subroutine
	subroutine fftshift1d (arr)
		complex, dimension (:), intent (inout)	:: arr
		integer									:: n1, i1
		complex, allocatable, dimension(:)		:: temp

		n1 = size (arr, 1)
		allocate (temp (n1))

		do i1=n1/2+1, n1
			temp (i1 - n1/2) = arr (i1)
		end do
		do i1=1, n1/2
			temp (i1 + n1/2) = arr (i1)
		end do
		arr = temp
		deallocate (temp)
	end subroutine
	subroutine rfftshift1d (arr)
		real, dimension (:), intent (inout)	:: arr
		integer								:: n1, i1
		real, allocatable, dimension(:)		:: temp

		n1 = size (arr, 1)
		allocate (temp (n1))

		do i1=n1/2+1, n1
			temp (i1 - n1/2) = arr (i1)
		end do
		do i1=1, n1/2
			temp (i1 + n1/2) = arr (i1)
		end do
		arr = temp
		deallocate (temp)
	end subroutine
end module
