program gpdesig
	
	use sep
	use base_fftwfl_mod
	use base_fftwv3_mod
	implicit none
	
	integer, external	:: sreed, srite
	integer				:: n1,n2,n3,nt,nf
	real				:: d1,o1,dt,ot,df,of
	integer				:: b,e
	integer				:: ii,jj,kk
	
	real,allocatable	:: gdata(:),tdata(:),temp(:),taper(:)
	complex,allocatable	:: fdata(:)
	
	integer*8			:: fft_for,fft_inv
	logical				:: true_t,verbose,nodesig
	
	real, parameter		:: pi=3.1415926535
	
	real				:: la,f0,sg,w0,f,w,eps
	complex,allocatable	:: sensy(:)

	real				:: delt
	integer				:: delti

	call sep_init()
	call from_param('verbose',verbose,.false.)
	call from_param('verb'	 ,verbose,verbose)
	call from_param('nodesig' ,nodesig, .false.)
	if (verbose) write(0,*) '-------------------------------------------'
	if (verbose) write(0,*) '				 GEOPHONE DESIGNATURE							'
	if (verbose) write(0,*) '-------------------------------------------'
	
	call from_history('n1',n1,1 )
	call from_history('n2',n2,1 )
	call from_history('n3',n3,1 )
	call from_history('d1',d1,1.)
	call from_history('o1',o1,0.)
	call from_param('eps',eps,.01)
	
	call from_param('true_t',true_t,.true.)
	if (verbose) write(0,*) 'true_t',true_t

	! Determine how to treat time axis. true_t means to actually consider the value of o1 from the input.
	if (true_t) then
		ot = minval( (/o1,-abs(o1+n1*d1)/) )
		dt = d1
		nt = nint(-ot/d1*2)	! this effectively does zero-padding, with the most extreme time available in the data reaching one end.
		b	= nint((o1-ot)/d1)+1	! index where the data begins in the input array
		e	= b+n1-1		! index where the data ends in the input array
	else
		ot=	0.
		dt= d1
		nt= n1
		b =	1
		e = b+n1-1
	end if

	! Fourier units
	of = 0.
	df = 1./(nt*dt)
	nf = nt/2+1

	if (verbose) write(0,*) 'n1,d1,o1',n1,d1,o1
	if (verbose) write(0,*) 'nt,dt,ot',nt,dt,ot
	if (verbose) write(0,*) 'nf,df,of',nf,df,of
	if (verbose) write(0,*) 'Defining FT axis as (-t,t): ',ot,ot+(nt-1)*d1
	if (verbose) write(0,*) 'read data into indices: ',b,e,'out of',nt
	
	call from_param('delt',delt,.120) ! taper length

	call from_param('la',la,68.25)		! Damping, in percent
	call from_param('sg',sg,.2095*100)	! V/(cm/s) -> V/(m/s)
	call from_param('f0',f0,10.)		! Central instrument freq (i.e., a "10Hz geophone")
	call from_param('w0',w0,2*pi*f0)

	call sep_close()
	
	allocate(gdata(n1),tdata(nt),fdata(nf),temp(nt/2),taper(n1),sensy(nf))
	call sfftw_plan_dft_r2c_1d(fft_for, nt,	tdata, fdata, FFTW_ESTIMATE);
	call sfftw_plan_dft_c2r_1d(fft_inv, nt,	fdata, tdata, FFTW_ESTIMATE);

	! Construct Taper
	delti=nint(delt/d1)
	if (verbose) write(0,*) 'delti',delti,delt,d1
	taper=1;
	if (delti.gt.0) then
		do ii=1,delti
			taper(ii)= 1-.5*(1.+cos(pi*(ii-1)/real(delti)))
		end do
		do ii=1,delti
			taper(n1-ii+1)= 1-.5*(1.+cos(pi*(ii-1)/real(delti)))
		end do
	end if

	! Taper as output
	if (exist_file("taper")) then
		if (verbose) write(0,*) 'write taper to file'
		call to_history("n1", n1 ,"taper")
		call to_history("d1", d1 ,"taper")
		call to_history("o1", o1 ,"taper")
		if (srite("taper",taper,4*n1) .eq. 0) call seperr ("error writing taper");
	end if	

	if (exist_file("amp")) then
		if (verbose) write(0,*) 'write amplitude to file'
		call to_history("n1", nf ,"amp")
		call to_history("d1", df ,"amp")
		call to_history("o1", of ,"amp")
		call to_history("n2", n2 ,"amp")
	end if	

	if (exist_file("sensy")) then
		if (verbose) write(0,*) 'write phase correction to file'
		call to_history("n1", nf ,"sensy")
		call to_history("d1", df ,"sensy")
		call to_history("o1", of ,"sensy")
	end if	

	! Prepare geophone sensitivity
	sensy = 0.
	do ii=1,nf
		f = (ii-1)*df
		w = 2*pi*f
		sensy(ii) = sg*(w**2./w0**2.)/((-w**2./w0**2.)+cmplx(1,2*la/100.*w/w0))
	end do
	if (exist_file("sensy")) then
		if (srite ("sensy", aimag (clog (conjg(sensy))), 4*size(sensy)) .eq. 0) call seperr ("error writing designature function");
	endif
	eps = eps*(sum(cabs(sensy)))/nf

	! pass data through as-is if nodesig option is selected	
	if (nodesig) then
		write (0,*), "NOT RUNNING DESIGNATURE on this dataset"
		do kk=1,n3
		do jj=1,n2
			if (sreed ("in" , gdata, n1*4) .eq. 0) call seperr ("error reading input data");
			if (srite ("out" , gdata, n1*4) .eq. 0) call seperr ("error writing output data");
		end do
		end do
	! else apply designature
	else

		do kk=1,n3
		do jj=1,n2
			gdata=0; tdata=0; fdata=0;
	
			if (sreed ("in" , gdata, n1*4) .eq. 0) call seperr ("error reading input data");
	
			tdata(b:e)=gdata*taper
	
			! shift and FT transform. The negative times need to be placed at the second half of the array.
			temp			 = tdata(     1:nt/2)
			tdata(1:nt/2)	 = tdata(nt/2+1:nt  )
			tdata(nt/2+1:nt) = temp
			call sfftw_execute( fft_for )
	
			if (exist_file("amp")) then
	        	if (srite('amp',abs(fdata),4*size(fdata)) .eq. 0) call seperr ("error writing amplitude");
			endif
	
			! apply designature
			fdata = fdata*conjg(sensy)/(sensy*conjg(sensy)+eps)
	
			! FT inverse transform and shift.
			call sfftw_execute( fft_inv )
			temp				 = tdata(nt/2+1:nt  )
			tdata(nt/2+1:nt	)	 = tdata(	 1:nt/2)
			tdata(		 1:nt/2) = temp
			gdata=tdata(b:e)/nt
	
			if (srite ("out" , gdata, n1*4) .eq. 0) call seperr ("error writing output data");
		end do
		end do

	endif

	if (verbose) write(0,*) '-------------------------------------------'
	call sfftw_destroy_plan(fft_for,fft_inv)
	deallocate(gdata,tdata,fdata,temp,taper,sensy)
	call exit(0)

end program

