module integ_mod
	use sep

	implicit none

	integer	:: n1_in
	real	:: d1_in, o1_in
	integer	:: nwind 		! total number of integ. windows
	real	:: dwind, owind
	integer	:: n_wind		! number of elements within integ. window

contains

subroutine integrate_init (n1, o1, d1, wind)
	integer,	intent(in)	:: n1
	real,		intent(in)	:: d1, o1
	real, optional,	intent(in)	:: wind

	n1_in = n1
	o1_in = o1
	d1_in = d1

	dwind = d1_in
	nwind = n1_in
	owind = o1_in

	if (.not. (present (wind))) then
		n_wind = 1
	else
		n_wind = wind / dwind
	endif

end subroutine

subroutine integrate_wind (ain, aout)

	real, dimension (:), intent(in)		:: ain
	real, dimension (:), intent(inout)	:: aout

	integer							:: i, iwind
	real							:: tot

	! loop over integration windows. iwind is index at center of time window.
	do iwind = n_wind / 2 + 1, n1_in - n_wind / 2
		tot = 0.

		do i = iwind - n_wind / 2, iwind + n_wind / 2
			tot = tot + d1_in * abs (ain (i))
		end do
		aout (iwind) = tot
	end do

end subroutine

subroutine integrate (ain, aout)

	real, dimension (:), intent(in)		:: ain
	real, dimension (:), intent(inout)	:: aout

	integer							:: i
	real							:: tot


	tot = 0.	
	tot = tot + 0.5 * d1_in * ain(1)
	do i = 2, n1_in
		tot = tot + d1_in * ain(i)
		aout(i) = tot
	end do

end subroutine
end module integ_mod
