! correlate two traces, and gauge the lag time between them by the envelope of the correlation.
program lagtrace
	use sep
	use corr_mod
	use env_mod

	implicit none

	real, parameter						:: pi=4.*atan(1.)
	integer, external					:: srite, sreed
	real, allocatable, dimension (:,:)	:: F1, F2			! input data
	real, allocatable, dimension (:,:)	:: Fout			! output data
	real, allocatable, dimension (:,:)	:: corr, env
	real, allocatable, dimension (:,:)	:: spec			! input spectrum
	integer								:: n1, n2, n3	! data dimensions
	integer								:: cn1			! correlated trace length
	integer								:: i1, i2, i3	! counters
	integer								:: ftpad1, ftpad2	! how much zero padding.
	real								:: d1, d2, d3, o1, o2, o3, co1
	logical								:: do_corr	! whether to write out the correlation
	logical								:: do_env	! whether to write out the enevelope
	integer*8							:: plan			! for fourier transform
	character (len=256)					:: sfile
	character (len=64)					:: label1, label2, label3
	integer								:: tape1, tape2			! size of taper applied to edges of data
	real, allocatable, dimension (:)	:: tmp1, tmp2
	integer								:: stat
	integer								:: ilag(1)

	call sep_init()

	call from_aux ("file1","n1", n1)
	call from_aux ("file1","d1", d1)
	call from_aux ("file1","o1", o1)
	call from_aux ("file1","label1", label1, "")
	call from_aux ("file1","n2", n2, 1)
	call from_aux ("file1","d2", d2, 1.)
	call from_aux ("file1","o2", o2, 0.)
	call from_aux ("file1","label2", label2, "")
	call from_aux ("file1","n3", n3, 1)
	call from_aux ("file1","d3", d3, 1.)
	call from_aux ("file1","o3", o3, 0.)
	call from_aux ("file1","label3", label3, "")

	cn1 = n1*2-1
	co1 = -INT(cn1/2) * d1

	! write out lag history file parameters
	call sep_put_data_axis_par ("out", 1, n2, o2, d2, label2)
	call sep_put_data_axis_par ("out", 2, n3, o3, d3, label3)

	! write correlation file history
	do_corr=.false.
	call from_param ("corr", sfile, "none")
	if (sfile(1:4) /= "none") then
		do_corr=.true.
		call sep_put_data_axis_par ("corr", 1, cn1, co1, d1, label1)
		call sep_put_data_axis_par ("corr", 2, n2, o2, d2, label2)
		call sep_put_data_axis_par ("corr", 3, n3, o3, d3, label3)
	endif

	! write envelope file history
	do_env=.false.
	call from_param ("env", sfile, "none")
	if (sfile(1:4) /= "none") then
		do_env=.true.
		call sep_put_data_axis_par ("env", 1, cn1, co1, d1, label1)
		call sep_put_data_axis_par ("env", 2, n2, o2, d2, label2)
		call sep_put_data_axis_par ("env", 3, n3, o3, d3, label3)
	endif
	
	call sep_close()

	allocate (F1 (n1, n2))
	allocate (F2 (n1, n2))
	allocate (Fout (n1, n2))
	allocate (corr (cn1, n2))
	allocate (env (cn1, n2))
	corr = 0.
	env  = 0.

	! loop over 2d slices
	do i3=1, n3
		! read from input file 
		if (sreed ("file1", F1, n1 * n2 * sizeof (F1 (1,1))) .eq. 0) call seperr ("error reading input");
		if (sreed ("file2", F2, n1 * n2 * sizeof (F2 (1,1))) .eq. 0) call seperr ("error reading input");


		do i2=1,n2
			call correlateme (F1 (:,i2), F2 (:,i2), corr (:,i2), size (F1, 1), size (F2, 1))
		end do

		if (do_corr) then
			if (srite ("corr", corr, cn1 * n2 * sizeof (corr (1,1))) .eq. 0) call seperr ("error writing correlation to output");
		endif

		env = corr
		write (0,*), ""
		call envelope (env)
		write (0,*), ""

		if (do_env) then
			if (srite ("env", env, cn1 * n2 * sizeof (env (1,1))) .eq. 0) call seperr ("error writing envelope to output");
		endif

		do i2=1,n2
			ilag = maxloc (abs(corr(:,i2))) - n1
			if (srite ("out", real(ilag(1))*d1, 4) .eq. 0) call seperr ("error writing trace lag to output");
			!write (0,*), "trace ", i2, "lag ", ilag(1)
			!if (ilag(1) .gt. 0) then
			!	Fout (1:n1-ilag(1), i2) = F1 (ilag(1):n1, i2) ! lag up
			!elseif (ilag(1) .lt. 0) then
			!	Fout (abs(ilag(1)):n1, i2) = F1 (1:n1-abs(ilag(1)), i2) ! lag down
			!else
			!	Fout (:, i2) = F1 (:, i2)
			!endif

		end do

		!if (srite ("out", Fout, n1 * n2 * sizeof (Fout (1,1))) .eq. 0) call seperr ("error writing to output");
	end do

end program
