module linfit_mod
	implicit none

contains
	! do least-square fitting of data points in a 1D array to a line
	subroutine linfit1d (y, d1, o1, min1, max1)
		real, dimension (:), intent(inout)	:: y
		real, intent (in)					:: d1, o1, min1, max1
		integer								:: n1, i1, nx
		real, allocatable, dimension (:)	:: x
		real								:: a, b
		integer								:: imin1, imax1


		n1 = size (y)
		allocate (x (n1))


		imin1 = INT (min1/d1)
		imax1 = INT (max1/d1) + 1
		nx = imax1 - imin1 + 1

		do i1=1, n1
			x (i1) = o1+(i1-1)*d1
		end do

		! a = (avg(y) * sum(x^2) - avg(x) * sum (x*y)) / (sum (x^2) - n * avg(x)^2)
		! b = (sum(x*y) - n * avg(x) * avg(y))         / (sum (x^2) - n * avg(x)^2)

		a = (sum (y(imin1:imax1),1)/nx * sum (x(imin1:imax1)**2,1) - sum (x(imin1:imax1),1)/nx * sum (x(imin1:imax1)*y(imin1:imax1),1)) / (sum (x(imin1:imax1)**2,1) - nx*(sum (x(imin1:imax1),1)/nx)**2)

		b = (sum (x(imin1:imax1)*y(imin1:imax1),1) - nx * sum (x(imin1:imax1),1)/nx * sum (y(imin1:imax1),1)/nx) / (sum (x(imin1:imax1)**2,1) - nx*(sum (x(imin1:imax1),1)/nx)**2)

		y = a + b * x

	end subroutine


end module
