! calculate the phase difference between the signals on input1 and input 2
program phasediffcalc
	use sep
	use base_fftwfl_mod
	use base_fftwv3_mod
	use fftshift_mod
	use unwrap
	use divstack_mod
	use wind_mod
	use triangle
	use linfit_mod

	implicit none

	real, parameter						:: pi=4.*atan(1.)
	integer, external					:: srite, sreed
	real, allocatable, dimension (:)	:: data1, data2			! input data
	real, allocatable, dimension (:,:)	:: phase1, phase2, amp1, amp2, unrap1, unrap2
	real, allocatable, dimension (:,:)	:: phasediff
	complex, allocatable, dimension (:,:)	:: cphasediff
	real, allocatable, dimension (:)	:: phasestack, tmp1, rphasestack, iphasestack, linphase
	real, allocatable, dimension (:)	:: taper1
	real, allocatable, dimension (:)	:: data1_t, data2_t
	complex, allocatable, dimension (:)	:: data1_f, data2_f
	complex, allocatable, dimension (:,:)	:: data1_f2d, data2_f2d
	integer								:: n1, n2, n3, nt	! data dimensions
	integer								:: nf, fn2		! dimensions in fourier space
	integer								:: i1, i2, i3, iw	! counters
	real								:: d1, d2, d3, dt, df, o1, o2, o3, ot, of
	logical								:: do_phase = .false.	! whether to write out the phases
	logical								:: do_amp = .false.	! whether to write out the amplitudes
	logical								:: do_unrap = .false.	! whether to write out the amplitudes
	logical								:: do_phased = .false.	! whether to write out the phase difference
	logical								:: do_sphased = .false.	! whether to write out the stacked phase difference
	logical								:: do_lphased = .false.	! whether to write out the linearly fitted phase difference
	logical								:: true_t
	logical								:: verbose
	logical								:: noneg
	character (len=256)					:: sfile
	character (len=64)					:: label1, label2, label3
	integer								:: ntape1		 			! size of taper applied to edges of data along the time axis
	real								:: tape1
	integer								:: rect1					! smoothing window size for phase difference
	integer								:: winlen					! window length for diversity stacking of phase differences
	integer								:: w1, stat
	integer								:: bt, et
	integer*8							:: plan1, plan2, plan3		! for fourier transform
	real								:: minamp1, minamp2
	real								:: eps
	real								:: fmin, fmax				! range in which linear fit to phase difference will be calculated
	

	call sep_init()

	call from_aux ("file1","n1", n1)
	call from_aux ("file1","d1", d1)
	call from_aux ("file1","o1", o1)
	call from_aux ("file1","label1", label1, " ")
	call from_aux ("file1","n2", n2, 1)
	call from_aux ("file1","d2", d2, 1.)
	call from_aux ("file1","o2", o2, 0.)
	call from_aux ("file1","label2", label2, " ")
	call from_aux ("file1","n3", n3, 1)
	call from_aux ("file1","d3", d3, 1.)
	call from_aux ("file1","o3", o3, 0.)
	call from_aux ("file1","label3", label3, " ")

	
	call from_param ("verb", verbose, .false.)
	call from_param ("tape1", tape1, 0.)
	call from_param ("eps", eps, 1e-2)
	call from_param ("rect1", rect1, 1)
	call from_param ("winlen", winlen, n1)
	call from_param ("noneg", noneg, .false.)
	call from_param('true_t',true_t,.true.)

	! Determine how to treat time axis. true_t means to actually consider the value of o1 from the input.
	if (true_t) then
		ot = minval( (/o1,-abs(o1+n1*d1)/) )
		dt = d1
		nt = nint(-ot/d1*2)	! this effectively does zero-padding, with the most extreme time available in the data reaching one end.
		bt = nint((o1-ot)/d1)+1	! index where the data begins in the input array
		et = bt+n1-1		! index where the data ends in the input array
	else
		ot = 0.
		dt = d1
		nt = n1
		bt = 1
		et = bt+n1-1
	end if

	! Fourier parameters
	nf = nt/2+1
	df = 1./(dt*nt)
	of = 0.

	call from_param('fmin',fmin,of)
	call from_param('fmax',fmax,of+df*(nf-1))

	if (verbose) write(0,*), 'tape1', tape1
	if (verbose) write(0,*), 'eps', eps
	if (verbose) write(0,*), 'fmin,fmax', fmin,fmax
	if (verbose) write(0,*), 'rect1', rect1
	if (verbose) write(0,*), 'winlen', winlen
	if (verbose) write(0,*), 'noneg', noneg
	if (verbose) write(0,*), 'true_t', true_t
	if (verbose) write(0,*) 'n1,d1,o1',n1,d1,o1
	if (verbose) write(0,*) 'nt,dt,ot',nt,dt,ot
	if (verbose) write(0,*) 'nf,df,of',nf,df,of
	if (verbose) write(0,*) 'Defining FT axis as (-t,t): ',ot,ot+(nt-1)*d1
	if (verbose) write(0,*) 'read data into indices: ',bt,et,'out of',nt

	! write output file history
	call to_history ("n1", n1)
	call to_history ("o1", o1)
	call to_history ("d1", d1)
	call to_history ("label1", label1)
	call to_history ("n2", n2)
	call to_history ("o2", o2)
	call to_history ("d2", d2)
	call to_history ("label2", label2)
	call to_history ("n3", n3)
	call to_history ("o3", o3)
	call to_history ("d3", d3)
	call to_history ("label3", label3)

	! write phase file history
	if (exist_file ("phase")) then
		do_phase=.true.
		call sep_put_data_axis_par ("phase", 1, nf, of, df, "frequency (Hz)")
		call sep_put_data_axis_par ("phase", 2, n2, o2, d2, label2)
		call sep_put_data_axis_par ("phase", 3, 2*n3, o3, d3, label3)
	endif

	! write amplitude file history
	if (exist_file ("amp")) then
		do_amp=.true.
		call sep_put_data_axis_par ("amp", 1, nf, of, df, "frequency (Hz)")
		call sep_put_data_axis_par ("amp", 2, n2, o2, d2, label2)
		call sep_put_data_axis_par ("amp", 3, 2*n3, o3, d3, label3)
	endif

	! write unwrapped phase file history
	if (exist_file ("unrap")) then
		do_unrap=.true.
		call sep_put_data_axis_par ("unrap", 1, nf, of, df, "frequency (Hz)")
		call sep_put_data_axis_par ("unrap", 2, n2, o2, d2, label2)
		call sep_put_data_axis_par ("unrap", 3, 2*n3, o3, d3, label3)
	endif

	! write phase difference file history
	if (exist_file ("phased")) then
		do_phased=.true.
		call sep_put_data_axis_par ("phased", 1, nf, of, df, "frequency (Hz)")
		call sep_put_data_axis_par ("phased", 2, n2, o2, d2, label2)
		call sep_put_data_axis_par ("phased", 3, n3, o3, d3, label3)
	endif

	! write phase difference file history
	if (exist_file ("sphased")) then
		do_sphased=.true.
		call sep_put_data_axis_par ("sphased", 1, nf, of, df, "frequency (Hz)")
		call sep_put_data_axis_par ("sphased", 2, n3, o3, d3, label3)
	endif

	! write linearly fitted phase difference file history
	if (exist_file ("lphased")) then
		do_lphased=.true.
		call sep_put_data_axis_par ("lphased", 1, nf, of, df, "frequency (Hz)")
		call sep_put_data_axis_par ("lphased", 2, n3, o3, d3, label3)
	endif

	call sep_close ()

	allocate (data1		(n1))
	allocate (data2		(n1))
	allocate (data1_t	(nt))
	allocate (data2_t	(nt))
	allocate (data1_f	(nf))
	allocate (data2_f	(nf))
	allocate (data1_f2d	(nf, n2))
	allocate (data2_f2d	(nf, n2))
	allocate (phase1	(nf ,n2))
	allocate (phase2	(nf ,n2))
	allocate (amp1		(nf ,n2))
	allocate (amp2		(nf ,n2))
	allocate (unrap1	(nf ,n2))
	allocate (unrap2	(nf ,n2))
	allocate (phasediff	(nf, n2))
	allocate (cphasediff	(nf, n2))
	allocate (phasestack(nf))
	allocate (iphasestack(nf))
	allocate (rphasestack(nf))
	allocate (linphase(nf))
	allocate (tmp1		(nf))
	allocate (taper1	(n1))


	! Construct Taper
	ntape1=nint(tape1/d1)
	if (verbose) write(0,*) 'ntape1=',ntape1, "tape1=", tape1
	taper1=1
	if (ntape1.gt.0) then
		do i1=1,ntape1
			taper1 (i1)			= 1-.5*(1.+cos(pi*(i1-1)/real(ntape1)))
			taper1 (n1-i1+1)	= 1-.5*(1.+cos(pi*(i1-1)/real(ntape1)))
		end do
	end if

	! output taper
	if (exist_file("taper")) then
		call to_history("n1", n1 ,"taper")
		call to_history("d1", d1 ,"taper")
		call to_history("o1", o1 ,"taper")
		if (srite ("taper", taper1, 4*n1) .eq. 0) call seperr ("error writing taper");
	end if	


	call sfftw_plan_dft_r2c_1d(plan1, nt, data1_t, data1_f, FFTW_ESTIMATE);
	call sfftw_plan_dft_r2c_1d(plan2, nt, data2_t, data2_f, FFTW_ESTIMATE);
	call sfftw_plan_dft_c2r_1d(plan3, nt, data1_f, data1_t, FFTW_ESTIMATE);

	! loop over 2d slices
	do i3=1, n3
		data1_f2d=0.; data2_f2d=0.; phase1=0.; phase2=0.; amp1=0.; amp2=0.; unrap1=0.; unrap2=0.
		do i2=1,n2
			data1=0.; data2=0.; data1_t=0.; data2_t=0.; data1_f=0.; data2_f=0.
			! read from input file 
			if (sreed ("file1", data1, n1 * sizeof (data1 (1))) .eq. 0) call seperr ("error reading input");
			if (sreed ("file2", data2, n1 * sizeof (data2 (1))) .eq. 0) call seperr ("error reading input");

			! put data into correct indices array to be transformed
			data1_t (bt:et) = data1*taper1
			data2_t (bt:et) = data2*taper1

			! shift so that positive times are from index 1->nt/2, and negative times from nt/2+1->nt (ascending)
			call rfftshift1d (data1_t)
			call rfftshift1d (data2_t)

			! FT
			call sfftw_execute(plan1)
			call sfftw_execute(plan2)
			data1_f2d (:, i2) = data1_f (:)
			data2_f2d (:, i2) = data2_f (:)

			! calculate instantaneous phase and amplitude
			phase1 (:,i2)  = aimag (clog (data1_f))
			phase2 (:,i2)  = aimag (clog (data2_f))
			amp1 (:,i2)    = cabs(data1_f) / nf
			amp2 (:,i2)    = cabs(data2_f) / nf

			! calculate the unwrapped phase derivative
			unrap1 (:,i2) = phase1 (:,i2)
			unrap2 (:,i2) = phase2 (:,i2)

			minamp1 = eps * maxval (amp1 (:,i2), 1)
			minamp2 = eps * maxval (amp2 (:,i2), 1)

			! calculate the unwrapped phase
			call unwrap_simple (unrap1(:,i2), amp1(:,i2), minamp1)
			call unwrap_simple (unrap2(:,i2), amp2(:,i2), minamp2)

			phasediff (:, i2) = (unrap2 (:,i2) - unrap1 (:,i2)) * 1.0
		end do


		! decompose phase difference into real and complex parts, average each part separately and recalculate phase angle of average
		cphasediff = cexp (cmplx (0., phasediff))
		call divstack (real(cphasediff),  rphasestack, winlen)
		call divstack (aimag(cphasediff), iphasestack, winlen)
		phasestack = aimag (clog (cmplx (rphasestack, iphasestack)))

		if (noneg) then
			do i1= 1, nf
				if (phasestack (i1) .lt. 0) then
					phasestack (i1) = phasestack (i1) + 2*pi
				endif
			end do
		endif

		! smooth the phase difference
		call triangle_init (rect1, nf)
		stat = triangle_lop (.false., .false., phasestack, tmp1)
		stat = triangle_lop (.false., .false., tmp1, phasestack)
		call triangle_close ()

		linphase = phasestack
		call linfit1d (linphase, df, of, fmin, fmax)


		! rotate the phase of input 1 to match phase of input 2
		do i2 = 1, n2
			!data1_f (:)  = data1_f2d (:,i2) * cexp ( cmplx (0., phasestack))		! rotate by stacked phase difference
			data1_f (:)  = data1_f2d (:,i2) * cexp ( cmplx (0., linphase))			! rotate by linearly-fitted phase difference
	
			call sfftw_execute (plan3)		! inverse transform
			call rfftshift1d (data1_t)		! shift back to original time arrangement
			data1 = data1_t (bt:et) / nt	! put data back into correct indices in output array
			if (srite ("out", data1, n1 * sizeof (data1 (1))) .eq. 0) call seperr ("error writing to output");		! print out phase rotated data
		end do

		! print out phase, amplitude, unwrapped phase if requested
		if (do_phase) then
			if (srite ("phase", phase1, nf * n2 * sizeof (phase1 (1,1))) .eq. 0) call seperr ("error writing phase to output");
			if (srite ("phase", phase2, nf * n2 * sizeof (phase2 (1,1))) .eq. 0) call seperr ("error writing phase to output");
		endif
		if (do_amp) then
			if (srite ("amp", amp1, nf * n2 * sizeof (amp1 (1,1))) .eq. 0) call seperr ("error writing amplitude to output");
			if (srite ("amp", amp2, nf * n2 * sizeof (amp2 (1,1))) .eq. 0) call seperr ("error writing amplitude to output");
		endif
		if (do_unrap) then
			if (srite ("unrap", unrap1, nf * n2 * sizeof (unrap1 (1,1))) .eq. 0) call seperr ("error writing unwrapped phase to output");
			if (srite ("unrap", unrap2, nf * n2 * sizeof (unrap2 (1,1))) .eq. 0) call seperr ("error writing unwrapped phase to output");
		endif
		if (do_phased) then
			if (srite ("phased", phasediff, nf * n2 * sizeof (phasediff (1,1))) .eq. 0) call seperr ("error writing phase difference to output");
		endif
		if (do_sphased) then
			if (srite ("sphased", phasestack/pi*180., nf * sizeof (phasestack (1))) .eq. 0) call seperr ("error writing stacked phase difference to output");
		endif
		if (do_lphased) then
			if (srite ("lphased", linphase/pi*180., nf * sizeof (linphase (1))) .eq. 0) call seperr ("error writing linearly fittend phase difference to output");
		endif


	end do

	call sfftw_destroy_plan(plan1)
	call sfftw_destroy_plan(plan2)
	call sfftw_destroy_plan(plan3)



end program
