! shift the phase of the input file according to a phase file
program phaseshift
	use sep
	use base_fftwfl_mod
	use base_fftwv3_mod
	use fftshift_mod

	implicit none

	real, parameter						:: pi=4.*atan(1.)
	integer, external					:: srite, sreed
	real, allocatable, dimension (:,:)	:: data1
	real, allocatable, dimension (:)	:: phase
	real, allocatable, dimension (:)		:: data1_t
	complex, allocatable, dimension (:)		:: data1_f
	integer								:: n1, n2, n3, nt	! data dimensions
	integer								:: nf, pn1		! dimensions in fourier space
	integer								:: i1, i2, i3 	! counters
	real								:: d1, d2, d3, dt, pd1, df, o1, o2, o3, ot, of, po1
	character (len=64)					:: label1, label2, label3
	integer*8							:: plan1, plan2		! for fourier transform
	real								:: degrees, eps
	integer								:: bt, et
	logical								:: true_t

	call sep_init()


	call from_history ("n1", n1)
	call from_history ("o1", o1)
	call from_history ("d1", d1)
	call from_history ("label1", label1, "")
	call from_history ("n2", n2, 1)
	call from_history ("o2", o2, 0.)
	call from_history ("d2", d2, 1.)
	call from_history ("label2", label2, "")
	call from_history ("n3", n3, 1)
	call from_history ("o3", o3, 0.)
	call from_history ("d3", d3, 1.)
	call from_history ("label3", label3, "")

	call to_history ("n1", n1)
	call to_history ("o1", o1)
	call to_history ("d1", d1)
	call to_history ("label1", label1)
	call to_history ("n2", n2)
	call to_history ("o2", o2)
	call to_history ("d2", d2)
	call to_history ("label2", label2)
	call to_history ("n3", n3)
	call to_history ("o3", o3)
	call to_history ("d3", d3)
	call to_history ("label3", label3)

	call from_param ("eps", eps, 1e-3)
	call from_param ("true_t", true_t, .true.)
	call from_param ("degrees", degrees, 0.)
	degrees = degrees * pi / 180.

	! Determine how to treat time axis. true_t means to actually consider the value of o1 from the input.
	if (true_t) then
		ot = minval( (/o1,-abs(o1+n1*d1)/) )
		dt = d1
		nt = nint(-ot/d1*2)	! this effectively does zero-padding, with the most extreme time available in the data reaching one end.
		bt = nint((o1-ot)/d1)+1	! index where the data begins in the input array
		et = bt+n1-1		! index where the data ends in the input array
	else
		ot = 0.
		dt = d1
		nt = n1
		bt = 1
		et = bt+n1-1
	end if

	nf = nt/2+1
	df = 1. / (dt * nt)
	of = 0.


	allocate (data1		(n1, n2))
	allocate (data1_t	(nt))
	allocate (data1_f	(nf))
	allocate (phase		(nf))

	if (exist_file ("phase")) then
		call from_aux ("phase","n1", pn1)
		call from_aux ("phase","d1", pd1)
		call from_aux ("phase","o1", po1)
		if (nf .ne. pn1) call seperr ("phaseshift: n1 of phase file does not match number of frequencies of input file. This is required so that Fourier transform of input will have equal length to that of phase file.")
		if (df .gt. pd1+eps .or. df .lt. pd1-eps) call seperr ("phaseshift: d1 of phase file does not match frequency sampling of input file. ")
		if (of .gt. po1+eps .or. of .lt. po1-eps) call seperr ("phaseshift: o1 of phase file does not match frequency origin of input file. ")
		if (sreed ("phase", phase, nf * sizeof (phase (1))) .eq. 0) call seperr ("error reading input from phase file");
		phase = phase * pi / 180.
	else
		phase = degrees
	endif

	call sfftw_plan_dft_r2c_1d (plan1, nt, data1_t, data1_f, FFTW_ESTIMATE)
	call sfftw_plan_dft_c2r_1d (plan2, nt, data1_f, data1_t, FFTW_ESTIMATE)

	! loop over 2d slices
	do i3=1, n3
		! read from input file 
		if (sreed ("in", data1, n1 * n2 * sizeof (data1 (1,1))) .eq. 0) call seperr ("error reading input");
		
		! FT
		do i2=1,n2
			data1_t = 0.; data1_f = 0.

			! put data in correct indices of array to be transformed
			data1_t (bt:et) = data1 (:, i2)

			! shift so that positive times are from index 1->nt/2, and negative times from nt/2+1->nt (ascending)
			call rfftshift1d (data1_t)

			! FT
			call sfftw_execute(plan1)

			! phase shift
			data1_f = data1_f * cexp (cmplx (0., phase))

			! inverse FT
			call sfftw_execute(plan2)		! inverse transform
			call rfftshift1d (data1_t)		! shift back to original time arrangement
			data1 (:, i2) = data1_t (bt:et) / nt ! put back into correct indices in output array
			
		end do

		! print out phase-rotated output
		if (srite ("out", data1, n1 * n2 * sizeof (data1 (1,1))) .eq. 0) call seperr ("error writing to output");

	end do

	call sfftw_destroy_plan(plan1)
	call sfftw_destroy_plan(plan2)

end program
