program sdrLogLog
  ! Program to talke a trace and construct a complex trace containing x and y
  ! representing the (x,y) scatters of that trace in log-log scale

  ! When X-axis is converted to log scale, it excludes DC (if opt: 2 or 3)

  use sep
  implicit none

  integer                  :: n1,n2,n3,n4,n5,n6
  real                     :: d1,o1
  integer                  :: ii,jj,kk,ll,mm,nn

  real,   allocatable      :: data_in(:)
  real,   allocatable      :: axis_x(:)
  complex,allocatable      :: data_out(:)
  
  integer                  :: opt       ! (1: normal scatter, 2: log-log scater, 3: log-normal scatter, 4: normal-log scatter)

  call sep_init()

  ! Read from History
  call from_history("n1",n1,1 )
  call from_history("n2",n2,1 )
  call from_history("n3",n3,1 )
  call from_history("n4",n4,1 )
  call from_history("n5",n5,1 )
  call from_history("n6",n6,1 )
  call from_history("o1",o1,0.)
  call from_history("d1",d1,1.)
  
  ! From Paremeters
  call from_param("opt",opt,2) 

  ! To History
  call to_history("esize",8 )
  if (o1.eq.0.) then
    if (opt.eq.2.or.opt.eq.3) then
      call to_history("n1",n1-1)
    else
      call to_history("n1",n1  )
    end if
  else
    call to_history("n1",n1  )
  end if
  call to_history("o1",1. )
  call to_history("d1",1. )

  call sep_close()

  ! Allocate Memory
  allocate(data_in(n1),data_out(n1),axis_x(n1))

  ! Create X-axis
  do ii=1,n1
    axis_x(ii)=o1+(ii-1)*d1
  end do
  
  ! Optionally convert to Log scale
  if (opt.eq.2.or.opt.eq.3) then; axis_x = log10(axis_x); end if 

  do nn=1,n6 
  do mm=1,n5 
  do ll=1,n4 
  do kk=1,n3 
  do jj=1,n2
     
    ! Read Data trace 
    call sreed( "in",data_in ,4*n1)
 
    ! Optionally convert to Log scale
    if (opt.eq.2.or.opt.eq.4) then;
      where (data_in.eq.0.); data_in=0.0000000000001; end where
      data_in = log10(data_in);
    end if 

    ! Construct complex trace
    data_out=cmplx( axis_x, data_in )
    
    ! Write trace
    if (o1.eq.0.) then
      if (opt.eq.2.or.opt.eq.3) then
        call srite("out",data_out(2:n1),8*(n1-1))
      else
        call srite("out",data_out,8*n1)
      end if
    else
      if (opt.eq.2.or.opt.eq.3) then
        call srite("out",data_out(2:n1),8*(n1-1))
      else
        call srite("out",data_out,8*n1)
      end if
      call srite("out",data_out,8*n1)
    end if 
 
  end do
  end do
  end do
  end do
  end do
 
  ! Deallocate Memory
  deallocate(data_in,data_out)

end program
