% generate rotations, and record the projection of a constant magnetic field on the rotated frame.
echo off;
clear all;
close all;

deg2rad = pi/180.;

% parameters for morlet wavelet
lb=-4;
ub=4.;
n=256;
wavelet = morlet (lb, ub, n);

% constant ambient magnetic field in nanoTeslas
B_North=23236;
B_East=4945;
B_Down=41942;

% declination of ambient field is 12.015 degrees
Declination= 12.015 * deg2rad;

% X component oriented toward 120 degrees from North
% Y component oriented toward 30 degrees from North
Xorient = 120 * deg2rad;
Yorient = 30  * deg2rad;

% angle difference between horizontal magnetic sensors and the Earth's field
Theta = Yorient-Declination;

% projection of ambient magnetic field on magnetic components
Bx = B_East * cos(-Theta) - B_North * sin(-Theta);
By = B_East * sin(-Theta) + B_North * cos(-Theta);
Bz = B_Down;

B = [Bx; By; Bz ];

% create rotation traces
rad1=1.;

Rx =  1e-7*rad1.*wavelet;
Ry =  1e-5*rad1.*wavelet;
Rz =  1e-6*rad1.*wavelet;

Bdata = zeros (3,n);
S     = zeros (3,3,n);

% generate rotations matrices for each time step and rotate the projection of magnetic field B on the rotated frame.
for it=1:n
	Rmatrix(1, 1, it) =  cos(Ry(it))*cos(Rz(it));
	Rmatrix(1, 2, it) = -cos(Ry(it))*sin(Rz(it));
	Rmatrix(1, 3, it) =  sin(Ry(it));
	Rmatrix(2, 1, it) =  cos(Rx(it))*sin(Rz(it)) + cos(Rz(it))*sin(Rx(it))*sin(Ry(it));
	Rmatrix(2, 2, it) =  cos(Rx(it))*cos(Rz(it)) - sin(Rx(it))*sin(Ry(it))*sin(Rz(it));
	Rmatrix(2, 3, it) = -cos(Ry(it))*sin(Rx(it));
	Rmatrix(3, 1, it) =  sin(Rx(it))*sin(Rz(it)) - cos(Rx(it))*cos(Rz(it))*sin(Ry(it));
	Rmatrix(3, 2, it) =  cos(Rz(it))*sin(Rx(it)) + cos(Rx(it))*sin(Ry(it))*sin(Rz(it));
	Rmatrix(3, 3, it) =  cos(Rx(it))*cos(Ry(it));

	Bdata (:,it) = Rmatrix (:,:,it) * B;

end

[U, S, V] = svd (Bdata, 0);
Vs = abs (S*V')';

% show rotations
figure;
	plot (Rx, 'k'); hold on;
	plot (Ry, 'b'); hold on;
	plot (Rz, 'r'); hold on;
	legend ('Rx','Ry','Rz');

% show magnetic projections
figure;
	plot (Bdata (1,:), 'k'); hold on;
	plot (Bdata (2,:), 'b'); hold on;
	plot (Bdata (3,:), 'r'); hold on;
	legend ('Bx','By','Bz');

% show singular values
figure;
	plot (log(Vs(:,1)), 'k'); hold on;
	plot (log(Vs(:,2)), 'b'); hold on;
	plot (log(Vs(:,3)), 'r'); hold on;
	legend ('S1','S2','S3');
