module unwrap 
  use cgstep_mod
  use igrad1
  use solver_smp_mod
  implicit none


  contains
  subroutine grad1init( z, n1, rt )
    integer  i,  n1
    real                 rt(n1)
    complex               z(n1),a,c
    rt = 0.
    do i= 1, n1-1  
        a =  z(i)        
        c =  z(i+1)
        rt(i) =  aimag( clog( c * conjg( a) ) )
    end do
  end subroutine 
! Phase unwraper.   Starting from phase hh, improve it.
  subroutine unwraper( zz, hh, niter)
    integer  n1, niter
    complex              zz(:)
    real                 hh(:)
    real, allocatable ::  rt(:)

    n1 = size (zz,1) 
    allocate (rt(n1))

    call grad1init (zz, n1, rt)
    call solver_smp (m=hh, d=rt, Fop=igrad1_lop, stepper=cgstep, niter=niter, m0=hh)
    call cgstep_close ()
	hh = rt
    deallocate (rt)
  end subroutine 

	subroutine unwrap_simple (phase, amp, thresh)
		real, parameter	:: pi=4.*atan(1.)
		real	:: phase(:), amp (:)
		real	:: thresh
		integer	:: i1, n1

		n1 = size (phase,1)

		do i1 = 2, n1
			if (amp(i1) .gt. thresh) then
				if (phase (i1) - phase (i1-1) .gt. pi) then
					phase (i1:n1) = phase(i1:n1) - 2*pi
				elseif (phase (i1) - phase (i1-1) .lt. -pi) then
					phase (i1:n1) = phase (i1:n1) + 2*pi
				endif
			endif
		end do
		
	end subroutine
end module 
