module wind_mod
	use sep
	implicit none
	contains

subroutine window1d (ain, o1, d1, b1, e1, tape1)
	real, dimension (:), intent (inout)	:: ain
	real, intent(in)	:: o1, d1 ! parameters of data
	real, intent(in)	:: b1, e1 ! parameters of window
	integer, intent(in)	:: tape1
	integer	:: n1, ib1, ie1, i1
	real	:: w1
	real, parameter	:: pi=4.*atan(1.)

	n1 = size (ain, 1)

	if (tape1 .lt. 0) call seperr ("window2d: length of taper along dimension 1 cannot be less than zero")
	if (tape1 .gt. n1/2) call seperr ("window2d: length of taper along dimension 1 cannot be greater than half-length of dimension 1")
	if (b1 .lt. o1) call seperr ("window2d: window beginning b1 cannot be less data beginning o1")
	if (e1 .gt. o1+(n1-1)*d1) call seperr ("window2d: window end e1 cannot be greater than end of data in axis 1")

	ib1 = (b1-o1)/d1 + 1
	ie1 = (e1-o1)/d1 + 1

	do i1=1, n1
		w1 = 1.

		if (i1 .lt. ib1) then
			w1 = 0.
		elseif (i1 .ge. ib1 .and. i1 .lt. ib1+tape1) then
			w1 = cos (0.5*pi*(REAL(i1-ib1)/REAL(tape1+1)))**2
		elseif (i1 .gt. ie1-tape1 .and. i1 .le. ie1) then
			w1 = 1. - cos (0.5*pi*(REAL(i1-(ie1-tape1))/REAL(tape1+1)))**2
		elseif (i1 .gt. ie1) then
			w1=0
		endif
			
		ain (i1) = ain (i1) * w1
	end do
end subroutine

subroutine window2d (ain, o1, d1, o2, d2, b1, e1, b2, e2, tape1, tape2)
	real, dimension (:,:), intent (inout)	:: ain
	real, intent(in)	:: o1, d1, o2, d2 ! parameters of data
	real, intent(in)	:: b1, e1, b2, e2 ! parameters of window
	integer, intent(in)	:: tape1, tape2
	integer	:: n1, n2, ib1, ie1, ib2, ie2, i1, i2
	real	:: w1, w2
	real, parameter	:: pi=4.*atan(1.)

	n1 = size (ain, 1)
	n2 = size (ain, 2)

	if (tape1 .lt. 0) call seperr ("window2d: length of taper along dimension 1 cannot be less than zero")
	if (tape2 .lt. 0) call seperr ("window2d: length of taper along dimension 2 cannot be less than zero")
	if (tape1 .gt. n1/2) call seperr ("window2d: length of taper along dimension 1 cannot be greater than half-length of dimension 1")
	if (tape2 .gt. n2/2) call seperr ("window2d: length of taper along dimension 2 cannot be greater than half-length of dimension 2")
	if (b1 .lt. o1) call seperr ("window2d: window beginning b1 cannot be less data beginning o1")
	if (b2 .lt. o2) call seperr ("window2d: window beginning b2 cannot be less data beginning o2")
	if (e1 .gt. o1+(n1-1)*d1) call seperr ("window2d: window end e1 cannot be greater than end of data in axis 1")
	if (e2 .gt. o2+(n2-1)*d2) call seperr ("window2d: window end e2 cannot be greater than end of data in axis 2")

	ib1 = (b1-o1)/d1 + 1
	ie1 = (e1-o1)/d1 + 1
	ib2 = (b2-o2)/d2 + 1
	ie2 = (e2-o2)/d2 + 1

	do i2=1, n2
		w2 = 1.

		if (i2 .lt. ib2) then
			w2 = 0.
		elseif (i2 .ge. ib2 .and. i2 .lt. ib2+tape2) then
			w2 = cos (0.5*pi*(REAL(i2-ib2)/REAL(tape2+1)))**2
		elseif (i2 .gt. ie2-tape2 .and. i2 .le. ie2) then
			w2 = 1. - cos (0.5*pi*(REAL(i2-(ie2-tape2))/REAL(tape2+1)))**2
		elseif (i2 .gt. ie2) then
			w2 = 0.
		endif

		do i1=1, n1
			w1 = 1.

			if (i1 .lt. ib1) then
				w1 = 0.
			elseif (i1 .ge. ib1 .and. i1 .lt. ib1+tape1) then
				w1 = cos (0.5*pi*(REAL(i1-ib1)/REAL(tape1+1)))**2
			elseif (i1 .gt. ie1-tape1 .and. i1 .le. ie1) then
				w1 = 1. - cos (0.5*pi*(REAL(i1-(ie1-tape1))/REAL(tape1+1)))**2
			elseif (i1 .gt. ie1) then
				w1=0
			endif
			
			ain (i1, i2) = ain (i1, i2) * w1 * w2
		end do
	end do
end subroutine
end module
